@@ -18,8 +18,8 @@ from PyQt6.QtCore import pyqtSlot, Qt
 from PyQt6.QtGui import QFontMetricsF, QGuiApplication
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QListWidgetItem
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_BlackConfigurationDialog import Ui_BlackConfigurationDialog
 
