@@ -25,7 +25,7 @@ from PyQt6.QtWidgets import (
     QTreeWidgetItem,
 )
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_BlackFormattingDialog import Ui_BlackFormattingDialog
 
@@ -33,8 +33,7 @@ from . import BlackUtilities
 from .BlackDiffWidget import BlackDiffWidget
 from .BlackFormattingAction import BlackFormattingAction
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class BlackFormattingDialog(QDialog, Ui_BlackFormattingDialog):
