@@ -12,8 +12,8 @@ import os
 from PyQt6.QtCore import pyqtSlot
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .Ui_CycloneDXConfigDialog import Ui_CycloneDXConfigDialog
 
