@@ -39,10 +39,10 @@ from PyQt6.QtWidgets import (
     QSplitter,
 )
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences
 
-from EricWidgets.EricTabWidget import EricTabWidget
+from eric7.EricWidgets.EricTabWidget import EricTabWidget
 
 
 class DebugViewer(QWidget):
@@ -94,7 +94,7 @@ class DebugViewer(QWidget):
         self.debugServer = debugServer
         self.debugUI = None
 
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
+        self.setWindowIcon(EricPixmapCache.getIcon("eric"))
 
         self.__mainLayout = QVBoxLayout()
         self.__mainLayout.setContentsMargins(0, 3, 0, 0)
@@ -126,24 +126,33 @@ class DebugViewer(QWidget):
         from .VariablesViewer import VariablesViewer
 
         # add the global variables viewer
-        self.glvWidget = QWidget()
-        self.glvWidgetVLayout = QVBoxLayout(self.glvWidget)
-        self.glvWidgetVLayout.setContentsMargins(0, 0, 0, 0)
-        self.glvWidgetVLayout.setSpacing(3)
-        self.glvWidget.setLayout(self.glvWidgetVLayout)
+        self.gvvWidget = QWidget()
+        self.gvvWidgetVLayout = QVBoxLayout(self.gvvWidget)
+        self.gvvWidgetVLayout.setContentsMargins(0, 0, 0, 0)
+        self.gvvWidgetVLayout.setSpacing(3)
+        self.gvvWidget.setLayout(self.gvvWidgetVLayout)
 
-        self.globalsViewer = VariablesViewer(self, True, self.glvWidget)
-        self.glvWidgetVLayout.addWidget(self.globalsViewer)
+        self.globalsViewer = VariablesViewer(self, True, self.gvvWidget)
+        self.gvvWidgetVLayout.addWidget(self.globalsViewer)
 
-        self.glvWidgetHLayout = QHBoxLayout()
-        self.glvWidgetHLayout.setContentsMargins(3, 3, 3, 3)
+        self.gvvWidgetHLayout = QHBoxLayout()
+        self.gvvWidgetHLayout.setContentsMargins(3, 3, 3, 3)
 
-        # TODO: add a switch between "Show Only" and "Don't Show"
-        self.globalsFilterEdit = QLineEdit(self.glvWidget)
+        self.globalsFilterTypeCombo = QComboBox(self.gvvWidget)
+        self.globalsFilterTypeCombo.setSizeAdjustPolicy(
+            QComboBox.SizeAdjustPolicy.AdjustToContents
+        )
+        self.globalsFilterTypeCombo.addItems(
+            [self.tr("Don't Show"), self.tr("Show Only")]
+        )
+        self.gvvWidgetHLayout.addWidget(self.globalsFilterTypeCombo)
+
+        self.globalsFilterEdit = QLineEdit(self.gvvWidget)
         self.globalsFilterEdit.setSizePolicy(
             QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed
         )
-        self.glvWidgetHLayout.addWidget(self.globalsFilterEdit)
+        self.globalsFilterEdit.setClearButtonEnabled(True)
+        self.gvvWidgetHLayout.addWidget(self.globalsFilterEdit)
         self.globalsFilterEdit.setToolTip(
             self.tr(
                 "Enter regular expression patterns separated by ';'"
@@ -159,12 +168,12 @@ class DebugViewer(QWidget):
             )
         )
 
-        self.setGlobalsFilterButton = QPushButton(self.tr("Set"), self.glvWidget)
-        self.glvWidgetHLayout.addWidget(self.setGlobalsFilterButton)
-        self.glvWidgetVLayout.addLayout(self.glvWidgetHLayout)
+        self.setGlobalsFilterButton = QPushButton(self.tr("Set"), self.gvvWidget)
+        self.gvvWidgetHLayout.addWidget(self.setGlobalsFilterButton)
+        self.gvvWidgetVLayout.addLayout(self.gvvWidgetHLayout)
 
         index = self.__tabWidget.addTab(
-            self.glvWidget, UI.PixmapCache.getIcon("globalVariables"), ""
+            self.gvvWidget, EricPixmapCache.getIcon("globalVariables"), ""
         )
         self.__tabWidget.setTabToolTip(
             index, self.tr("Shows the list of global variables and their values.")
@@ -174,38 +183,47 @@ class DebugViewer(QWidget):
         self.globalsFilterEdit.returnPressed.connect(self.setGlobalsFilter)
 
         # add the local variables viewer
-        self.lvWidget = QWidget()
-        self.lvWidgetVLayout = QVBoxLayout(self.lvWidget)
-        self.lvWidgetVLayout.setContentsMargins(0, 0, 0, 0)
-        self.lvWidgetVLayout.setSpacing(3)
-        self.lvWidget.setLayout(self.lvWidgetVLayout)
+        self.lvvWidget = QWidget()
+        self.lvvWidgetVLayout = QVBoxLayout(self.lvvWidget)
+        self.lvvWidgetVLayout.setContentsMargins(0, 0, 0, 0)
+        self.lvvWidgetVLayout.setSpacing(3)
+        self.lvvWidget.setLayout(self.lvvWidgetVLayout)
 
-        self.lvWidgetHLayout1 = QHBoxLayout()
-        self.lvWidgetHLayout1.setContentsMargins(3, 3, 3, 3)
+        self.lvvWidgetHLayout1 = QHBoxLayout()
+        self.lvvWidgetHLayout1.setContentsMargins(3, 3, 3, 3)
 
-        self.stackComboBox = QComboBox(self.lvWidget)
+        self.stackComboBox = QComboBox(self.lvvWidget)
         self.stackComboBox.setSizePolicy(
             QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed
         )
-        self.lvWidgetHLayout1.addWidget(self.stackComboBox)
+        self.lvvWidgetHLayout1.addWidget(self.stackComboBox)
 
-        self.sourceButton = QPushButton(self.tr("Source"), self.lvWidget)
-        self.lvWidgetHLayout1.addWidget(self.sourceButton)
+        self.sourceButton = QPushButton(self.tr("Source"), self.lvvWidget)
+        self.lvvWidgetHLayout1.addWidget(self.sourceButton)
         self.sourceButton.setEnabled(False)
-        self.lvWidgetVLayout.addLayout(self.lvWidgetHLayout1)
+        self.lvvWidgetVLayout.addLayout(self.lvvWidgetHLayout1)
 
-        self.localsViewer = VariablesViewer(self, False, self.lvWidget)
-        self.lvWidgetVLayout.addWidget(self.localsViewer)
+        self.localsViewer = VariablesViewer(self, False, self.lvvWidget)
+        self.lvvWidgetVLayout.addWidget(self.localsViewer)
 
-        self.lvWidgetHLayout2 = QHBoxLayout()
-        self.lvWidgetHLayout2.setContentsMargins(3, 3, 3, 3)
+        self.lvvWidgetHLayout2 = QHBoxLayout()
+        self.lvvWidgetHLayout2.setContentsMargins(3, 3, 3, 3)
 
-        # TODO: add a switch between "Show Only" and "Don't Show"
-        self.localsFilterEdit = QLineEdit(self.lvWidget)
+        self.localsFilterTypeCombo = QComboBox(self.lvvWidget)
+        self.localsFilterTypeCombo.setSizeAdjustPolicy(
+            QComboBox.SizeAdjustPolicy.AdjustToContents
+        )
+        self.localsFilterTypeCombo.addItems(
+            [self.tr("Don't Show"), self.tr("Show Only")]
+        )
+        self.lvvWidgetHLayout2.addWidget(self.localsFilterTypeCombo)
+
+        self.localsFilterEdit = QLineEdit(self.lvvWidget)
         self.localsFilterEdit.setSizePolicy(
             QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed
         )
-        self.lvWidgetHLayout2.addWidget(self.localsFilterEdit)
+        self.localsFilterEdit.setClearButtonEnabled(True)
+        self.lvvWidgetHLayout2.addWidget(self.localsFilterEdit)
         self.localsFilterEdit.setToolTip(
             self.tr(
                 "Enter regular expression patterns separated by ';' to define "
@@ -220,12 +238,12 @@ class DebugViewer(QWidget):
             )
         )
 
-        self.setLocalsFilterButton = QPushButton(self.tr("Set"), self.lvWidget)
-        self.lvWidgetHLayout2.addWidget(self.setLocalsFilterButton)
-        self.lvWidgetVLayout.addLayout(self.lvWidgetHLayout2)
+        self.setLocalsFilterButton = QPushButton(self.tr("Set"), self.lvvWidget)
+        self.lvvWidgetHLayout2.addWidget(self.setLocalsFilterButton)
+        self.lvvWidgetVLayout.addLayout(self.lvvWidgetHLayout2)
 
         index = self.__tabWidget.addTab(
-            self.lvWidget, UI.PixmapCache.getIcon("localVariables"), ""
+            self.lvvWidget, EricPixmapCache.getIcon("localVariables"), ""
         )
         self.__tabWidget.setTabToolTip(
             index, self.tr("Shows the list of local variables and their values.")
@@ -245,7 +263,7 @@ class DebugViewer(QWidget):
         # add the call stack viewer
         self.callStackViewer = CallStackViewer(self.debugServer)
         index = self.__tabWidget.addTab(
-            self.callStackViewer, UI.PixmapCache.getIcon("callStack"), ""
+            self.callStackViewer, EricPixmapCache.getIcon("callStack"), ""
         )
         self.__tabWidget.setTabToolTip(index, self.tr("Shows the current call stack."))
         self.callStackViewer.sourceFile.connect(self.sourceFile)
@@ -256,7 +274,7 @@ class DebugViewer(QWidget):
         # add the call trace viewer
         self.callTraceViewer = CallTraceViewer(self.debugServer, self)
         index = self.__tabWidget.addTab(
-            self.callTraceViewer, UI.PixmapCache.getIcon("callTrace"), ""
+            self.callTraceViewer, EricPixmapCache.getIcon("callTrace"), ""
         )
         self.__tabWidget.setTabToolTip(
             index, self.tr("Shows a trace of the program flow.")
@@ -269,7 +287,7 @@ class DebugViewer(QWidget):
         self.breakpointViewer = BreakPointViewer()
         self.breakpointViewer.setModel(self.debugServer.getBreakPointModel())
         index = self.__tabWidget.addTab(
-            self.breakpointViewer, UI.PixmapCache.getIcon("breakpoints"), ""
+            self.breakpointViewer, EricPixmapCache.getIcon("breakpoints"), ""
         )
         self.__tabWidget.setTabToolTip(
             index, self.tr("Shows a list of defined breakpoints.")
@@ -282,7 +300,7 @@ class DebugViewer(QWidget):
         self.watchpointViewer = WatchPointViewer()
         self.watchpointViewer.setModel(self.debugServer.getWatchPointModel())
         index = self.__tabWidget.addTab(
-            self.watchpointViewer, UI.PixmapCache.getIcon("watchpoints"), ""
+            self.watchpointViewer, EricPixmapCache.getIcon("watchpoints"), ""
         )
         self.__tabWidget.setTabToolTip(
             index, self.tr("Shows a list of defined watchpoints.")
@@ -293,26 +311,26 @@ class DebugViewer(QWidget):
         # add the exception logger
         self.exceptionLogger = ExceptionLogger()
         index = self.__tabWidget.addTab(
-            self.exceptionLogger, UI.PixmapCache.getIcon("exceptions"), ""
+            self.exceptionLogger, EricPixmapCache.getIcon("exceptions"), ""
         )
         self.__tabWidget.setTabToolTip(
             index, self.tr("Shows a list of raised exceptions.")
         )
 
-        from UI.PythonDisViewer import PythonDisViewer, PythonDisViewerModes
+        from eric7.UI.PythonDisViewer import PythonDisViewer, PythonDisViewerModes
 
         # add the Python disassembly viewer
         self.disassemblyViewer = PythonDisViewer(
             None, mode=PythonDisViewerModes.TRACEBACK
         )
         index = self.__tabWidget.addTab(
-            self.disassemblyViewer, UI.PixmapCache.getIcon("disassembly"), ""
+            self.disassemblyViewer, EricPixmapCache.getIcon("disassembly"), ""
         )
         self.__tabWidget.setTabToolTip(
             index, self.tr("Shows a code disassembly in case of an exception.")
         )
 
-        self.__tabWidget.setCurrentWidget(self.glvWidget)
+        self.__tabWidget.setCurrentWidget(self.gvvWidget)
 
         self.__doDebuggersListUpdate = True
 
@@ -378,7 +396,7 @@ class DebugViewer(QWidget):
         self.sourceButton.setEnabled(False)
         self.currentStack = None
         self.stackComboBox.clear()
-        self.__tabWidget.setCurrentWidget(self.glvWidget)
+        self.__tabWidget.setCurrentWidget(self.gvvWidget)
         self.breakpointViewer.handleResetUI()
         if fullReset:
             self.__debuggersList.clear()
@@ -457,9 +475,9 @@ class DebugViewer(QWidget):
         @type bool
         """
         if showGlobals:
-            self.__tabWidget.setCurrentWidget(self.glvWidget)
+            self.__tabWidget.setCurrentWidget(self.gvvWidget)
         else:
-            self.__tabWidget.setCurrentWidget(self.lvWidget)
+            self.__tabWidget.setCurrentWidget(self.lvvWidget)
 
     def handleClientStack(self, stack, debuggerId):
         """
@@ -617,11 +635,14 @@ class DebugViewer(QWidget):
         """
         if self.debugServer.isDebugging():
             filterStr = self.globalsFilterEdit.text()
+            if self.globalsFilterTypeCombo.currentIndex() == 0:
+                filterStr = "~ {0}".format(filterStr)
+            self.globalsViewer.clear()
             self.debugServer.remoteClientSetFilter(
                 self.getSelectedDebuggerId(), 1, filterStr
             )
             self.debugServer.remoteClientVariables(
-                self.getSelectedDebuggerId(), 2, self.__globalsFilter
+                self.getSelectedDebuggerId(), 1, self.__globalsFilter
             )
 
     def setLocalsFilter(self):
@@ -630,6 +651,9 @@ class DebugViewer(QWidget):
         """
         if self.debugServer.isDebugging():
             filterStr = self.localsFilterEdit.text()
+            if self.localsFilterTypeCombo.currentIndex() == 0:
+                filterStr = "~ {0}".format(filterStr)
+            self.localsViewer.clear()
             self.debugServer.remoteClientSetFilter(
                 self.getSelectedDebuggerId(), 0, filterStr
             )
@@ -638,6 +662,19 @@ class DebugViewer(QWidget):
                     self.getSelectedDebuggerId(), 0, self.__localsFilter, self.framenr
                 )
 
+    def refreshVariablesLists(self):
+        """
+        Public slot to refresh the local and global variables lists.
+        """
+        if self.debugServer.isDebugging():
+            self.debugServer.remoteClientVariables(
+                self.getSelectedDebuggerId(), 1, self.__globalsFilter
+            )
+            if self.currentStack:
+                self.debugServer.remoteClientVariables(
+                    self.getSelectedDebuggerId(), 0, self.__localsFilter, self.framenr
+                )
+
     def handleDebuggingStarted(self):
         """
         Public slot to handle the start of a debugging session.
@@ -832,7 +869,7 @@ class DebugViewer(QWidget):
                 stateText = DebugViewer.StateMessage[state]
             except KeyError:
                 stateText = self.tr("unknown state ({0})").format(state)
-            debuggerItem.setIcon(0, UI.PixmapCache.getIcon(iconName))
+            debuggerItem.setIcon(0, EricPixmapCache.getIcon(iconName))
             debuggerItem.setData(0, self.DebuggerStateRole, state)
             debuggerItem.setText(1, stateText)
 
@@ -897,7 +934,7 @@ class DebugViewer(QWidget):
                     iconName = DebugViewer.StateIcon["running"]
                 itm = QTreeWidgetItem(debuggerItem, [thread["name"], stateText])
                 itm.setData(0, self.ThreadIdRole, thread["id"])
-                itm.setIcon(0, UI.PixmapCache.getIcon(iconName))
+                itm.setIcon(0, EricPixmapCache.getIcon(iconName))
                 if currentChild == thread["name"]:
                     self.__debuggersList.setCurrentItem(itm)
                 if thread["id"] == currentID:
@@ -960,7 +997,7 @@ class DebugViewer(QWidget):
                     stateText = DebugViewer.StateMessage[state]
                 except KeyError:
                     stateText = self.tr("unknown state ({0})").format(state)
-                childItem.setIcon(0, UI.PixmapCache.getIcon(iconName))
+                childItem.setIcon(0, EricPixmapCache.getIcon(iconName))
                 childItem.setText(1, stateText)
 
             self.__debuggersList.header().resizeSections(
