@@ -21,7 +21,7 @@ from . import DebugClientCapabilities
 
 from eric7 import Globals, Preferences, Utilities
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 ClientDefaultCapabilities = DebugClientCapabilities.HasAll
