@@ -22,12 +22,11 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QBrush, QFontMetrics
 from PyQt6.QtWidgets import QTreeView, QAbstractItemView, QToolTip, QMenu
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Config import ConfigVarTypeDispStrings
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 SORT_ROLE = Qt.ItemDataRole.UserRole
 
@@ -275,11 +274,14 @@ class VariablesModel(QAbstractItemModel):
         Public method to update the data model of variable in pathlist.
 
         @param vlist the list of variables to be displayed. Each
-                list entry is a tuple of three values.
+                list entry is a tuple of six values.
                 <ul>
-                <li>the variable name (string)</li>
-                <li>the variables type (string)</li>
-                <li>the variables value (string)</li>
+                <li>the variable name (str)</li>
+                <li>list, tuple, dict or set indicator (str)</li>
+                <li>the variables type (str)</li>
+                <li>a flag indicating the presence of children (bool)</li>
+                <li>the length of the array or string (int)</li>
+                <li>the variables value (str)</li>
                 </ul>
         @type list of str
         @param frmnr frame number (0 is the current frame)
@@ -732,7 +734,7 @@ class VariablesModel(QAbstractItemModel):
         )
         ericApp().getObject("DebugServer").remoteClientVariable(
             ericApp().getObject("DebugUI").getSelectedDebuggerId(),
-            self.__globalScope,
+            1 if self.__globalScope else 0,
             variablesFilter,
             pathlist,
             self.framenr,
@@ -942,11 +944,14 @@ class VariablesViewer(QTreeView):
         Public method to show variables in a list.
 
         @param vlist the list of variables to be displayed. Each
-                list entry is a tuple of three values.
+                list entry is a tuple of six values.
                 <ul>
-                <li>the variable name (string)</li>
-                <li>the variables type (string)</li>
-                <li>the variables value (string)</li>
+                <li>the variable name (str)</li>
+                <li>list, tuple, dict or set indicator (str)</li>
+                <li>the variables type (str)</li>
+                <li>a flag indicating the presence of children (bool)</li>
+                <li>the length of the array or string (int)</li>
+                <li>the variables value (str)</li>
                 </ul>
         @type list
         @param frmnr frame number (0 is the current frame)
@@ -962,11 +967,14 @@ class VariablesViewer(QTreeView):
         @param vlist the list of subitems to be displayed.
                 The first element gives the path of the
                 parent variable. Each other list entry is
-                a tuple of three values.
+                a tuple of six values.
                 <ul>
-                <li>the variable name (string)</li>
-                <li>the variables type (string)</li>
-                <li>the variables value (string)</li>
+                <li>the variable name (str)</li>
+                <li>list, tuple, dict or set indicator (str)</li>
+                <li>the variables type (str)</li>
+                <li>a flag indicating the presence of children (bool)</li>
+                <li>the length of the array or string (int)</li>
+                <li>the variables value (str)</li>
                 </ul>
         @type list
         """
@@ -1159,6 +1167,12 @@ class VariablesViewer(QTreeView):
         """
         ericApp().getObject("DebugUI").dbgFilterAct.triggered.emit()
 
+    def clear(self):
+        """
+        Public method to clear the viewer.
+        """
+        self.varModel.clear()
+
 
 #
 # eflag: noqa = M822
