@@ -9,16 +9,18 @@ Module implementing some helpers for Google mail.
 
 import os
 
-import Globals
+from eric7 import Globals
+from eric7.EricWidgets.EricApplication import ericApp
 
-SCOPES = "https://www.googleapis.com/auth/gmail.send"
+SCOPES = ["https://www.googleapis.com/auth/gmail.send"]
 CLIENT_SECRET_FILE = "eric_client_secret.json"  # secok
 TOKEN_FILE = "eric_python_email_send_token.json"  # secok
 APPLICATION_NAME = "Eric Python Send Email"
 
 RequiredPackages = (
     "google-api-python-client",
-    "requests-oauthlib",
+    "google-auth-httplib2",
+    "google-auth-oauthlib",
 )
 
 
@@ -32,14 +34,9 @@ def isClientSecretFileAvailable():
     return os.path.exists(os.path.join(Globals.getConfigDir(), CLIENT_SECRET_FILE))
 
 
-def getInstallCommand():
+def installGoogleAPIPackages():
     """
-    Module function to get the install command to get the Google mail support
-    activated.
-
-    @return install command
-    @rtype str
+    Module function to install the required packages to support Google mail.
     """
-    pipCommand = "pip install --upgrade {0}".format(" ".join(RequiredPackages))
-
-    return pipCommand
+    pip = ericApp().getObject("Pip")
+    pip.installPackages(RequiredPackages, interpreter=Globals.getPythonExecutable())
