@@ -189,7 +189,7 @@ class EricApplication(QApplication):
         @rtype str
         """
         from eric7 import Preferences, Utilities
-        from eric7config import getConfig
+        from eric7.Globals import getConfig
 
         styleIconsPath = Preferences.getUI("StyleIconsPath")
         if not styleIconsPath:
