@@ -24,7 +24,7 @@ from PyQt6.QtWidgets import (
 from . import EricFileDialog
 from .EricCompleters import EricFileCompleter, EricDirCompleter
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class EricPathPickerModes(enum.Enum):
@@ -110,7 +110,7 @@ class EricPathPickerBase(QWidget):
 
         self.__button = QToolButton(self)
         self.__button.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
-        self.__button.setIcon(UI.PixmapCache.getIcon("open"))
+        self.__button.setIcon(EricPixmapCache.getIcon("open"))
 
         self.__layout.addWidget(self._editor)
         self.__layout.addWidget(self.__button)
