@@ -10,7 +10,7 @@ Module implementing a toolbar manager class.
 from PyQt6.QtCore import QObject, QByteArray, QDataStream, QIODevice
 from PyQt6.QtWidgets import QToolBar
 
-import Utilities
+from eric7 import Utilities
 
 
 class EricToolBarManager(QObject):
