@@ -7,7 +7,7 @@
 Module implementing a class for reading an XML session file.
 """
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Config import sessionFileFormatVersion
 from .XMLStreamReaderBase import XMLStreamReaderBase
