@@ -27,7 +27,10 @@ from PyQt6.QtCore import (
     qVersion,
 )
 
-from eric7config import getConfig
+try:
+    from eric7.eric7config import getConfig
+except ImportError:
+    from eric7config import getConfig
 
 # names of the various settings objects
 settingsNameOrganization = "Eric7"
@@ -616,7 +619,10 @@ def getWebBrowserSupport():
         or "None")
     @rtype str
     """
-    from eric7config import getConfig
+    try:
+        from eric7.eric7config import getConfig
+    except ImportError:
+        from eric7config import getConfig
 
     scriptPath = os.path.join(getConfig("ericDir"), "Tools", "webBrowserSupport.py")
     proc = QProcess()
