@@ -12,9 +12,9 @@ import enum
 from PyQt6.QtCore import QPointF, QRectF, QLineF
 from PyQt6.QtWidgets import QGraphicsItem
 
-from EricGraphics.EricArrowItem import EricArrowItem, EricArrowType
+from eric7.EricGraphics.EricArrowItem import EricArrowItem, EricArrowType
 
-import Utilities
+from eric7 import Utilities
 
 
 class AssociationType(enum.Enum):
