@@ -23,9 +23,9 @@ from PyQt6.QtWidgets import (
     QMenu,
 )
 
-from EricWidgets import EricFileDialog, EricMessageBox
+from eric7.EricWidgets import EricFileDialog, EricMessageBox
 
-import Preferences
+from eric7 import Preferences
 
 from .HelpBookmarkPropertiesDialog import HelpBookmarkPropertiesDialog
 
@@ -349,7 +349,7 @@ class HelpBookmarksWidget(QListWidget):
         @param items list of bookmarks to be deleted
         @type list of QListWidgetItem
         """
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self,
