@@ -24,7 +24,7 @@ from PyQt6.QtWidgets import QTextBrowser, QMenu
 
 from .HelpViewerImpl import HelpViewerImpl
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 AboutBlank = QCoreApplication.translate(
@@ -455,17 +455,17 @@ class HelpViewerImplQTB(HelpViewerImpl, QTextBrowser):
         selectedText = self.textCursor().selectedText()
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("back"), self.tr("Backward"), self.backward
+            EricPixmapCache.getIcon("back"), self.tr("Backward"), self.backward
         )
         act.setEnabled(self.isBackwardAvailable())
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("forward"), self.tr("Forward"), self.forward
+            EricPixmapCache.getIcon("forward"), self.tr("Forward"), self.forward
         )
         act.setEnabled(self.isForwardAvailable())
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("reload"), self.tr("Reload"), self.reload
+            EricPixmapCache.getIcon("reload"), self.tr("Reload"), self.reload
         )
 
         if not linkUrl.isEmpty() and linkUrl.scheme() != "javascript":
@@ -474,13 +474,13 @@ class HelpViewerImplQTB(HelpViewerImpl, QTextBrowser):
         self.__menu.addSeparator()
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy Page URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy Page URL to Clipboard")
         )
         act.setData(self.link())
         act.triggered.connect(functools.partial(self.__copyLink, act))
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("bookmark22"), self.tr("Bookmark Page")
+            EricPixmapCache.getIcon("bookmark22"), self.tr("Bookmark Page")
         )
         act.setData({"title": self.pageTitle(), "url": self.link()})
         act.triggered.connect(functools.partial(self.__bookmarkPage, act))
@@ -488,28 +488,28 @@ class HelpViewerImplQTB(HelpViewerImpl, QTextBrowser):
         self.__menu.addSeparator()
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("zoomIn"), self.tr("Zoom in"), self.scaleUp
+            EricPixmapCache.getIcon("zoomIn"), self.tr("Zoom in"), self.scaleUp
         )
         act.setEnabled(self.isScaleUpAvailable())
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("zoomOut"), self.tr("Zoom out"), self.scaleDown
+            EricPixmapCache.getIcon("zoomOut"), self.tr("Zoom out"), self.scaleDown
         )
         act.setEnabled(self.isScaleDownAvailable())
 
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("zoomReset"), self.tr("Zoom reset"), self.resetScale
+            EricPixmapCache.getIcon("zoomReset"), self.tr("Zoom reset"), self.resetScale
         )
 
         self.__menu.addSeparator()
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy"), self.copy
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy"), self.copy
         )
         act.setEnabled(bool(selectedText))
 
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("editSelectAll"),
+            EricPixmapCache.getIcon("editSelectAll"),
             self.tr("Select All"),
             self.selectAll,
         )
@@ -517,11 +517,11 @@ class HelpViewerImplQTB(HelpViewerImpl, QTextBrowser):
         self.__menu.addSeparator()
 
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("tabClose"), self.tr("Close"), self.__closePage
+            EricPixmapCache.getIcon("tabClose"), self.tr("Close"), self.__closePage
         )
 
         act = self.__menu.addAction(
-            UI.PixmapCache.getIcon("tabCloseOther"),
+            EricPixmapCache.getIcon("tabCloseOther"),
             self.tr("Close Others"),
             self.__closeOtherPages,
         )
@@ -542,13 +542,14 @@ class HelpViewerImplQTB(HelpViewerImpl, QTextBrowser):
             menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("openNewTab"), self.tr("Open Link in New Page")
+            EricPixmapCache.getIcon("openNewTab"), self.tr("Open Link in New Page")
         )
         act.setData(linkUrl)
         act.triggered.connect(functools.partial(self.__openLinkInNewPage, act))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("newWindow"), self.tr("Open Link in Background Page")
+            EricPixmapCache.getIcon("newWindow"),
+            self.tr("Open Link in Background Page"),
         )
         act.setData(linkUrl)
         act.triggered.connect(functools.partial(self.__openLinkInBackgroundPage, act))
@@ -556,7 +557,7 @@ class HelpViewerImplQTB(HelpViewerImpl, QTextBrowser):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy URL to Clipboard")
         )
         act.setData(linkUrl)
         act.triggered.connect(functools.partial(self.__copyLink, act))
