@@ -19,7 +19,7 @@ from PyQt6.QtWebEngineCore import QWebEnginePage, QWebEngineNewWindowRequest
 from .HelpViewerWidget import HelpViewerWidget
 from .HelpViewerImpl import HelpViewerImpl
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class HelpViewerImplQWE(HelpViewerImpl, QWebEngineView):
@@ -581,17 +581,17 @@ class HelpViewerImplQWE(HelpViewerImpl, QWebEngineView):
         contextMenuData = self.lastContextMenuRequest()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("back"), self.tr("Backward"), self.backward
+            EricPixmapCache.getIcon("back"), self.tr("Backward"), self.backward
         )
         act.setEnabled(self.isBackwardAvailable())
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("forward"), self.tr("Forward"), self.forward
+            EricPixmapCache.getIcon("forward"), self.tr("Forward"), self.forward
         )
         act.setEnabled(self.isForwardAvailable())
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("reload"), self.tr("Reload"), self.reload
+            EricPixmapCache.getIcon("reload"), self.tr("Reload"), self.reload
         )
 
         if (
@@ -603,13 +603,13 @@ class HelpViewerImplQWE(HelpViewerImpl, QWebEngineView):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy Page URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy Page URL to Clipboard")
         )
         act.setData(self.link())
         act.triggered.connect(functools.partial(self.__copyLink, act))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("bookmark22"), self.tr("Bookmark Page")
+            EricPixmapCache.getIcon("bookmark22"), self.tr("Bookmark Page")
         )
         act.setData({"title": self.pageTitle(), "url": self.link()})
         act.triggered.connect(functools.partial(self.__bookmarkPage, act))
@@ -617,28 +617,28 @@ class HelpViewerImplQWE(HelpViewerImpl, QWebEngineView):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("zoomIn"), self.tr("Zoom in"), self.scaleUp
+            EricPixmapCache.getIcon("zoomIn"), self.tr("Zoom in"), self.scaleUp
         )
         act.setEnabled(self.isScaleUpAvailable())
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("zoomOut"), self.tr("Zoom out"), self.scaleDown
+            EricPixmapCache.getIcon("zoomOut"), self.tr("Zoom out"), self.scaleDown
         )
         act.setEnabled(self.isScaleDownAvailable())
 
         menu.addAction(
-            UI.PixmapCache.getIcon("zoomReset"), self.tr("Zoom reset"), self.resetScale
+            EricPixmapCache.getIcon("zoomReset"), self.tr("Zoom reset"), self.resetScale
         )
 
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy"), self.__copyText
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy"), self.__copyText
         )
         act.setEnabled(bool(contextMenuData.selectedText()))
 
         menu.addAction(
-            UI.PixmapCache.getIcon("editSelectAll"),
+            EricPixmapCache.getIcon("editSelectAll"),
             self.tr("Select All"),
             self.__selectAll,
         )
@@ -646,11 +646,11 @@ class HelpViewerImplQWE(HelpViewerImpl, QWebEngineView):
         menu.addSeparator()
 
         menu.addAction(
-            UI.PixmapCache.getIcon("tabClose"), self.tr("Close"), self.__closePage
+            EricPixmapCache.getIcon("tabClose"), self.tr("Close"), self.__closePage
         )
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("tabCloseOther"),
+            EricPixmapCache.getIcon("tabCloseOther"),
             self.tr("Close Others"),
             self.__closeOtherPages,
         )
@@ -669,13 +669,14 @@ class HelpViewerImplQWE(HelpViewerImpl, QWebEngineView):
             menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("openNewTab"), self.tr("Open Link in New Page")
+            EricPixmapCache.getIcon("openNewTab"), self.tr("Open Link in New Page")
         )
         act.setData(contextMenuData.linkUrl())
         act.triggered.connect(functools.partial(self.__openLinkInNewPage, act))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("newWindow"), self.tr("Open Link in Background Page")
+            EricPixmapCache.getIcon("newWindow"),
+            self.tr("Open Link in Background Page"),
         )
         act.setData(contextMenuData.linkUrl())
         act.triggered.connect(functools.partial(self.__openLinkInBackgroundPage, act))
@@ -683,7 +684,7 @@ class HelpViewerImplQWE(HelpViewerImpl, QWebEngineView):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy URL to Clipboard")
         )
         act.setData(contextMenuData.linkUrl())
         act.triggered.connect(functools.partial(self.__copyLink, act))
