@@ -23,7 +23,7 @@ from PyQt6.QtCore import (
 
 from .MicroPythonSerialPort import MicroPythonSerialPort
 
-import Preferences
+from eric7 import Preferences
 
 
 class MicroPythonCommandsInterface(QObject):
