@@ -14,10 +14,10 @@ import os
 from PyQt6.QtCore import pyqtSlot, QObject, QCoreApplication
 from PyQt6.QtWidgets import QInputDialog
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences
 
 
 SupportedBoards = {
@@ -391,9 +391,9 @@ def getDeviceIcon(boardName, iconFormat=True):
     )
 
     if iconFormat:
-        return UI.PixmapCache.getIcon(iconName)
+        return EricPixmapCache.getIcon(iconName)
     else:
-        return UI.PixmapCache.getPixmap(iconName)
+        return EricPixmapCache.getPixmap(iconName)
 
 
 def getDevice(deviceType, microPythonWidget, vid, pid):
