@@ -15,17 +15,17 @@ import pathlib
 from PyQt6.QtCore import pyqtSignal, pyqtSlot, QFile, QIODevice, QObject, QUuid
 from PyQt6.QtWidgets import QMenu, QDialog, QToolBar
 
-from Globals import recentNameMultiProject
+from eric7.Globals import recentNameMultiProject
 
-from EricGui.EricAction import EricAction, createActionGroup
-from EricWidgets import EricFileDialog, EricMessageBox, EricPathPickerDialog
-from EricWidgets.EricPathPickerDialog import EricPathPickerModes
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricGui.EricAction import EricAction, createActionGroup
+from eric7.EricWidgets import EricFileDialog, EricMessageBox, EricPathPickerDialog
+from eric7.EricWidgets.EricPathPickerDialog import EricPathPickerModes
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Config
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 from .MultiProjectFile import MultiProjectFile
 
@@ -232,7 +232,7 @@ class MultiProject(QObject):
             f = QFile(fn)
             if f.open(QIODevice.OpenModeFlag.ReadOnly):
                 with EricOverrideCursor():
-                    from EricXML.MultiProjectReader import MultiProjectReader
+                    from eric7.EricXML.MultiProjectReader import MultiProjectReader
 
                     reader = MultiProjectReader(f, self)
                     reader.readXML()
@@ -701,7 +701,7 @@ class MultiProject(QObject):
 
         act = EricAction(
             self.tr("New multiproject"),
-            UI.PixmapCache.getIcon("multiProjectNew"),
+            EricPixmapCache.getIcon("multiProjectNew"),
             self.tr("&New..."),
             0,
             0,
@@ -721,7 +721,7 @@ class MultiProject(QObject):
 
         act = EricAction(
             self.tr("Open multiproject"),
-            UI.PixmapCache.getIcon("multiProjectOpen"),
+            EricPixmapCache.getIcon("multiProjectOpen"),
             self.tr("&Open..."),
             0,
             0,
@@ -739,7 +739,7 @@ class MultiProject(QObject):
 
         self.closeAct = EricAction(
             self.tr("Close multiproject"),
-            UI.PixmapCache.getIcon("multiProjectClose"),
+            EricPixmapCache.getIcon("multiProjectClose"),
             self.tr("&Close"),
             0,
             0,
@@ -757,7 +757,7 @@ class MultiProject(QObject):
 
         self.saveAct = EricAction(
             self.tr("Save multiproject"),
-            UI.PixmapCache.getIcon("multiProjectSave"),
+            EricPixmapCache.getIcon("multiProjectSave"),
             self.tr("&Save"),
             0,
             0,
@@ -773,7 +773,7 @@ class MultiProject(QObject):
 
         self.saveasAct = EricAction(
             self.tr("Save multiproject as"),
-            UI.PixmapCache.getIcon("multiProjectSaveAs"),
+            EricPixmapCache.getIcon("multiProjectSaveAs"),
             self.tr("Save &as..."),
             0,
             0,
@@ -794,7 +794,7 @@ class MultiProject(QObject):
 
         self.addProjectAct = EricAction(
             self.tr("Add project to multiproject"),
-            UI.PixmapCache.getIcon("fileProject"),
+            EricPixmapCache.getIcon("fileProject"),
             self.tr("Add &project..."),
             0,
             0,
@@ -816,7 +816,7 @@ class MultiProject(QObject):
 
         self.propsAct = EricAction(
             self.tr("Multiproject properties"),
-            UI.PixmapCache.getIcon("multiProjectProps"),
+            EricPixmapCache.getIcon("multiProjectProps"),
             self.tr("&Properties..."),
             0,
             0,
@@ -885,7 +885,7 @@ class MultiProject(QObject):
         @return the toolbar generated (QToolBar)
         """
         tb = QToolBar(self.tr("Multiproject"), self.ui)
-        tb.setIconSize(UI.Config.ToolBarIconSize)
+        tb.setIconSize(Config.ToolBarIconSize)
         tb.setObjectName("MultiProjectToolbar")
         tb.setToolTip(self.tr("Multiproject"))
 
