@@ -11,10 +11,9 @@ import copy
 
 from PyQt6.QtCore import pyqtSignal, QObject, QCoreApplication
 
-import Utilities
-from Utilities.AutoSaver import AutoSaver
-from Utilities.crypto import pwConvert
-import Preferences
+from eric7 import Preferences, Utilities
+from eric7.Utilities.AutoSaver import AutoSaver
+from eric7.Utilities.crypto import pwConvert
 
 
 class IrcIdentity:
