@@ -13,16 +13,15 @@ from PyQt6.QtCore import pyqtSlot, pyqtSignal, QPoint, QUrl, QThread
 from PyQt6.QtGui import QDesktopServices
 from PyQt6.QtWidgets import QWidget, QApplication, QMenu
 
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_IrcNetworkWidget import Ui_IrcNetworkWidget
 
 from .IrcUtilities import ircFilter, ircTimestamp
 
-import UI.PixmapCache
-import Preferences
-import Utilities
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences, Utilities
 
 
 class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
@@ -56,10 +55,10 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         super().__init__(parent)
         self.setupUi(self)
 
-        self.connectButton.setIcon(UI.PixmapCache.getIcon("ircConnect"))
-        self.editButton.setIcon(UI.PixmapCache.getIcon("ircConfigure"))
-        self.joinButton.setIcon(UI.PixmapCache.getIcon("ircJoinChannel"))
-        self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserPresent"))
+        self.connectButton.setIcon(EricPixmapCache.getIcon("ircConnect"))
+        self.editButton.setIcon(EricPixmapCache.getIcon("ircConfigure"))
+        self.joinButton.setIcon(EricPixmapCache.getIcon("ircJoinChannel"))
+        self.awayButton.setIcon(EricPixmapCache.getIcon("ircUserPresent"))
 
         self.joinButton.setEnabled(False)
         self.nickCombo.setEnabled(False)
@@ -191,13 +190,13 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
             # set being away
             # don't send away, if the status is already set
             self.sendData.emit("AWAY :" + awayMessage)
-            self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserAway"))
+            self.awayButton.setIcon(EricPixmapCache.getIcon("ircUserAway"))
             self.__away = True
             self.away.emit(self.__away)
         elif not awayMessage and self.__away:
             # cancel being away
             self.sendData.emit("AWAY")
-            self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserPresent"))
+            self.awayButton.setIcon(EricPixmapCache.getIcon("ircUserPresent"))
             self.__away = False
             self.away.emit(self.__away)
 
@@ -335,12 +334,12 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         """
         self.__connected = connected
         if self.__connected:
-            self.connectButton.setIcon(UI.PixmapCache.getIcon("ircDisconnect"))
+            self.connectButton.setIcon(EricPixmapCache.getIcon("ircDisconnect"))
             self.connectButton.setToolTip(
                 self.tr("Press to disconnect from the network")
             )
         else:
-            self.connectButton.setIcon(UI.PixmapCache.getIcon("ircConnect"))
+            self.connectButton.setIcon(EricPixmapCache.getIcon("ircConnect"))
             self.connectButton.setToolTip(
                 self.tr("Press to connect to the selected network")
             )
@@ -365,7 +364,7 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         self.nickCombo.setEnabled(registered)
         self.awayButton.setEnabled(registered)
         if registered:
-            self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserPresent"))
+            self.awayButton.setIcon(EricPixmapCache.getIcon("ircUserPresent"))
             self.__away = False
 
     def __clearMessages(self):
@@ -465,24 +464,28 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         """
         self.__messagesMenu = QMenu(self)
         self.__copyMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy"), self.__copyMessages
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy"), self.__copyMessages
         )
         self.__messagesMenu.addSeparator()
         self.__cutAllMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editCut"), self.tr("Cut all"), self.__cutAllMessages
+            EricPixmapCache.getIcon("editCut"),
+            self.tr("Cut all"),
+            self.__cutAllMessages,
         )
         self.__copyAllMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editCopy"),
+            EricPixmapCache.getIcon("editCopy"),
             self.tr("Copy all"),
             self.__copyAllMessages,
         )
         self.__messagesMenu.addSeparator()
         self.__clearMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("editDelete"), self.tr("Clear"), self.__clearMessages
+            EricPixmapCache.getIcon("editDelete"),
+            self.tr("Clear"),
+            self.__clearMessages,
         )
         self.__messagesMenu.addSeparator()
         self.__saveMessagesAct = self.__messagesMenu.addAction(
-            UI.PixmapCache.getIcon("fileSave"), self.tr("Save"), self.__saveMessages
+            EricPixmapCache.getIcon("fileSave"), self.tr("Save"), self.__saveMessages
         )
 
         self.on_messages_copyAvailable(False)
