@@ -16,22 +16,25 @@ from PyQt6.QtNetwork import QTcpSocket, QAbstractSocket
 
 try:
     from PyQt6.QtNetwork import QSslSocket, QSslConfiguration
-    from EricNetwork.EricSslErrorHandler import EricSslErrorHandler, EricSslErrorState
+    from eric7.EricNetwork.EricSslErrorHandler import (
+        EricSslErrorHandler,
+        EricSslErrorState,
+    )
 
     SSL_AVAILABLE = True
 except ImportError:
     SSL_AVAILABLE = False
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_IrcWidget import Ui_IrcWidget
 
-import Preferences
-import UI.PixmapCache
+from eric7 import Preferences
+from eric7.EricGui import EricPixmapCache
 
-from Globals import isMacPlatform
+from eric7.Globals import isMacPlatform
 
-from UI.Info import Version, Copyright
+from eric7.UI.Info import Version, Copyright
 
 
 class IrcWidget(QWidget, Ui_IrcWidget):
@@ -61,7 +64,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         self.__ircNetworkManager = IrcNetworkManager(self)
 
         self.__leaveButton = QToolButton(self)
-        self.__leaveButton.setIcon(UI.PixmapCache.getIcon("ircCloseChannel"))
+        self.__leaveButton.setIcon(EricPixmapCache.getIcon("ircCloseChannel"))
         self.__leaveButton.setToolTip(self.tr("Press to leave the current channel"))
         self.__leaveButton.clicked.connect(self.__leaveChannel)
         self.__leaveButton.setEnabled(False)
@@ -110,7 +113,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         self.__prefixRe = re.compile(r""".*\sPREFIX=\((.*)\)([^ ]+).*""")
         self.__chanTypesRe = re.compile(r""".*\sCHANTYPES=([^ ]+).*""")
 
-        ircPic = UI.PixmapCache.getPixmap("irc128")
+        ircPic = EricPixmapCache.getPixmap("irc128")
         self.__emptyLabel = QLabel()
         self.__emptyLabel.setPixmap(ircPic)
         self.__emptyLabel.setAlignment(
