@@ -28,15 +28,14 @@ from PyQt6.QtWidgets import (
     QVBoxLayout,
 )
 
-from EricWidgets import EricFileDialog
-from EricWidgets.EricMainWindow import EricMainWindow
+from eric7.EricWidgets import EricFileDialog
+from eric7.EricWidgets.EricMainWindow import EricMainWindow
 
 from .Ui_PluginInstallDialog import Ui_PluginInstallDialog
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
-from Utilities.uic import compileUiFiles
+from eric7.Utilities.uic import compileUiFiles
 
 
 class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
