@@ -64,7 +64,7 @@ from eric7 import Globals, Preferences, Utilities
 
 from eric7.EricGui import EricPixmapCache
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
