@@ -12,13 +12,13 @@ from PyQt6.QtWidgets import QDialog
 
 from .Ui_AboutDialog import Ui_AboutDialog
 
-import Preferences
+from eric7 import Preferences
 
-import UI.PixmapCache
-import UI.Info
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Info
 
 
-titleText = "<b>{0} - {1}</b>".format(UI.Info.Program, UI.Info.Version)
+titleText = "<b>{0} - {1}</b>".format(Info.Program, Info.Version)
 
 aboutText = QCoreApplication.translate(
     "AboutDialog",
@@ -33,7 +33,7 @@ aboutText = QCoreApplication.translate(
     """<p>{0} uses third party software which is copyrighted"""
     """ by its respective copyright holder. For details see"""
     """ the copyright notice of the individual package.</p>""",
-).format(UI.Info.Program, UI.Info.Homepage, UI.Info.BugAddress, UI.Info.FeatureAddress)
+).format(Info.Program, Info.Homepage, Info.BugAddress, Info.FeatureAddress)
 
 authorsText = """
 Detlev Offenbach
@@ -729,7 +729,7 @@ copy of the Program in return for a fee.
 
                      END OF TERMS AND CONDITIONS
 """
-).format(UI.Info.Copyright)
+).format(Info.Copyright)
 
 
 class AboutDialog(QDialog, Ui_AboutDialog):
@@ -748,7 +748,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         self.setWindowFlags(Qt.WindowType.Window)
 
         self.ericLabel.setText(titleText)
-        self.ericPixmap.setPixmap(UI.PixmapCache.getPixmap("eric").scaled(48, 48))
+        self.ericPixmap.setPixmap(EricPixmapCache.getPixmap("eric").scaled(48, 48))
 
         ####################################################################
         ## ABOUT
