@@ -369,7 +369,7 @@ class AnnotationsChecker:
         else:
             self.__error(arg.lineno - 1, arg.col_offset, errorCode)
 
-    @lru_cache()
+    @lru_cache()  # __IGNORE_WARNING_M519__
     def __returnErrorClassifier(self, isClassMethod, classDecoratorType, functionType):
         """
         Private method to classify a return type annotation issue.
@@ -400,7 +400,7 @@ class AnnotationsChecker:
         else:
             return "A201"
 
-    @lru_cache()
+    @lru_cache()  # __IGNORE_WARNING_M519__
     def __argumentErrorClassifier(
         self, isClassMethod, isFirstArg, classDecoratorType, annotationType
     ):
