@@ -14,6 +14,7 @@ AnnotationsCheckerDefaultArgs = {
     "AllowUntypedDefs": False,
     "AllowUntypedNested": False,
     "MypyInitReturn": False,
+    "AllowStarArgAny": False,
     "DispatchDecorators": ["singledispatch", "singledispatchmethod"],
     "OverloadDecorators": ["overload"],
     # Annotation Coverage
@@ -21,4 +22,6 @@ AnnotationsCheckerDefaultArgs = {
     # Annotation Complexity
     "MaximumComplexity": 3,
     "MaximumLength": 7,
+    # Annotations Future
+    "ForceFutureAnnotations": False,
 }
