@@ -20,12 +20,12 @@ from PyQt6.QtWidgets import (
     QHeaderView,
 )
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_SyntaxCheckerDialog import Ui_SyntaxCheckerDialog
 
-import Utilities
-import UI.PixmapCache
+from eric7 import Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
@@ -139,9 +139,9 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
         itm = QTreeWidgetItem(self.__lastFileItem)
         if isWarning:
-            itm.setIcon(0, UI.PixmapCache.getIcon("warning"))
+            itm.setIcon(0, EricPixmapCache.getIcon("warning"))
         else:
-            itm.setIcon(0, UI.PixmapCache.getIcon("syntaxError"))
+            itm.setIcon(0, EricPixmapCache.getIcon("syntaxError"))
         itm.setData(0, Qt.ItemDataRole.DisplayRole, line)
         itm.setData(1, Qt.ItemDataRole.DisplayRole, error)
         itm.setData(2, Qt.ItemDataRole.DisplayRole, sourcecode)
