@@ -19,7 +19,7 @@ from .Ui_EricapiConfigDialog import Ui_EricapiConfigDialog
 
 from eric7 import DocumentationTools, Globals, Utilities
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class EricapiConfigDialog(QDialog, Ui_EricapiConfigDialog):
