@@ -24,7 +24,7 @@ from eric7.DocumentationTools.Config import (
 
 from eric7 import Globals, Utilities
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
