@@ -19,7 +19,7 @@ from eric7.EricGui.EricAction import EricAction
 from eric7 import Utilities
 from eric7.UI import Info
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 # Start-Of-Header
 name = "Ericdoc Plugin"
