@@ -14,7 +14,7 @@ from PyQt6.QtCore import QObject
 
 from eric7.EricGui.EricAction import EricAction
 from eric7.EricWidgets.EricApplication import ericApp
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 from eric7.Project.ProjectBrowserModel import ProjectBrowserFileItem
 
