@@ -7,25 +7,30 @@
 Module implementing the translator widget.
 """
 
+import sys
+
 from PyQt6.QtCore import pyqtSlot, QTemporaryFile
 from PyQt6.QtWidgets import QWidget
 
-try:
-    from PyQt6.QtMultimedia import QMediaFormat, QMediaPlayer, QAudioOutput
-
-    MULTIMEDIA_AVAILABLE = True
-except ImportError:
+if "--no-multimedia" in sys.argv:
     MULTIMEDIA_AVAILABLE = False
+else:
+    try:
+        from PyQt6.QtMultimedia import QMediaFormat, QMediaPlayer, QAudioOutput
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+        MULTIMEDIA_AVAILABLE = True
+    except ImportError:
+        MULTIMEDIA_AVAILABLE = False
+
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_TranslatorWidget import Ui_TranslatorWidget
 
 from .TranslatorLanguagesDb import TranslatorLanguagesDb
 from . import TranslatorEngines
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class TranslatorWidget(QWidget, Ui_TranslatorWidget):
@@ -61,11 +66,19 @@ class TranslatorWidget(QWidget, Ui_TranslatorWidget):
 
         audioAvailable = False
         if MULTIMEDIA_AVAILABLE:
-            mediaFormat = QMediaFormat()
-            audioAvailable = (
-                QMediaFormat.AudioCodec.MP3
-                in mediaFormat.supportedAudioCodecs(QMediaFormat.ConversionMode.Decode)
-            )
+            if self.__plugin.getPreferences("MultimediaEnabled"):
+                mediaFormat = QMediaFormat()
+                audioAvailable = (
+                    QMediaFormat.AudioCodec.MP3
+                    in mediaFormat.supportedAudioCodecs(
+                        QMediaFormat.ConversionMode.Decode
+                    )
+                )
+            else:
+                audioAvailable = False
+        else:
+            # reset if multimedia was disabled via command line
+            self.__plugin.setPreferences("MultimediaEnabled", False)
         self.pronounceOrigButton.setVisible(audioAvailable)
         self.pronounceTransButton.setVisible(audioAvailable)
 
@@ -73,8 +86,8 @@ class TranslatorWidget(QWidget, Ui_TranslatorWidget):
         self.pronounceTransButton.setIcon(self.__translator.getAppIcon("pronounce"))
         self.swapButton.setIcon(self.__translator.getAppIcon("swap"))
         self.translateButton.setIcon(self.__translator.getAppIcon("translate"))
-        self.clearButton.setIcon(UI.PixmapCache.getIcon("editDelete"))
-        self.preferencesButton.setIcon(UI.PixmapCache.getIcon("configure"))
+        self.clearButton.setIcon(EricPixmapCache.getIcon("editDelete"))
+        self.preferencesButton.setIcon(EricPixmapCache.getIcon("configure"))
 
         self.translateButton.setEnabled(False)
         self.clearButton.setEnabled(False)
