@@ -26,19 +26,19 @@ from PyQt6.QtWidgets import (
     QInputDialog,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricGui.EricOverrideCursor import EricOverrideCursorProcess
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursorProcess
 
-from Globals import strToQByteArray
+from eric7.Globals import strToQByteArray
 
 from .Ui_GitLogBrowserDialog import Ui_GitLogBrowserDialog
 
 from .GitDiffHighlighter import GitDiffHighlighter
 from .GitDiffGenerator import GitDiffGenerator
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences
 
 COLORNAMES = [
     "red",
@@ -117,8 +117,8 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.filesTree.headerItem().setText(self.filesTree.columnCount(), "")
         self.filesTree.header().setSortIndicator(1, Qt.SortOrder.AscendingOrder)
 
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+        self.upButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(EricPixmapCache.getIcon("1downarrow"))
 
         self.refreshButton = self.buttonBox.addButton(
             self.tr("&Refresh"), QDialogButtonBox.ButtonRole.ActionRole
@@ -126,8 +126,8 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.refreshButton.setToolTip(self.tr("Press to refresh the list of commits"))
         self.refreshButton.setEnabled(False)
 
-        self.findPrevButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
-        self.findNextButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
+        self.findPrevButton.setIcon(EricPixmapCache.getIcon("1leftarrow"))
+        self.findNextButton.setIcon(EricPixmapCache.getIcon("1rightarrow"))
         self.__findBackwards = False
 
         self.modeComboBox.addItem(self.tr("Find"), "find")
@@ -157,6 +157,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.__detailsTemplate = self.tr(
             "<table>"
             "<tr><td><b>Commit ID</b></td><td>{0}</td></tr>"
+            "<tr><td colspan='2'>{10}</td></tr>"
             "<tr><td><b>Date</b></td><td>{1}</td></tr>"
             "<tr><td><b>Author</b></td><td>{2} &lt;{3}&gt;</td></tr>"
             "<tr><td><b>Commit Date</b></td><td>{4}</td></tr>"
@@ -179,6 +180,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.__formatTemplate = (
             "format:recordstart%n"
             "commit|%h%n"
+            "fullcommit|%H%n"
             "parents|%p%n"
             "author|%an%n"
             "authormail|%ae%n"
@@ -213,6 +215,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.__branchesRole = Qt.ItemDataRole.UserRole + 5
         self.__authorMailRole = Qt.ItemDataRole.UserRole + 6
         self.__committerMailRole = Qt.ItemDataRole.UserRole + 7
+        self.__fullCommitIdRole = Qt.ItemDataRole.UserRole + 8
 
         # roles used in the file tree
         self.__diffFileLineRole = Qt.ItemDataRole.UserRole
@@ -374,7 +377,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             self.tr("Show the most recent tag reachable from a commit")
         )
 
-        self.actionsButton.setIcon(UI.PixmapCache.getIcon("actionsToolButton"))
+        self.actionsButton.setIcon(EricPixmapCache.getIcon("actionsToolButton"))
         self.actionsButton.setMenu(self.__actionsMenu)
 
     def __initData(self):
@@ -681,6 +684,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         subject,
         message,
         commitId,
+        fullCommitId,
         changedPaths,
         parents,
         refnames,
@@ -697,6 +701,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         @param subject subject of the log entry (string)
         @param message text of the log message (list of strings)
         @param commitId commit id info (string)
+        @param fullCommitId unabbreviated commit id info (string)
         @param changedPaths list of dictionary objects containing
             info about the changed files/directories
         @param parents list of parent revisions (list of integers)
@@ -755,6 +760,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         itm.setData(0, self.__branchesRole, allBranches)
         itm.setData(0, self.__authorMailRole, authorMail)
         itm.setData(0, self.__committerMailRole, committerMail)
+        itm.setData(0, self.__fullCommitIdRole, fullCommitId)
         if not parents:
             itm.setData(0, self.__parentsRole, [])
         else:
@@ -960,6 +966,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             logEntry["subject"],
             logEntry["body"],
             logEntry["commit"],
+            logEntry["fullcommit"],
             logEntry["changed_files"],
             logEntry["parents"],
             logEntry["refnames"],
@@ -1049,6 +1056,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
                     value = line
                 if key in (
                     "commit",
+                    "fullcommit",
                     "parents",
                     "author",
                     "authormail",
@@ -1479,6 +1487,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
                 parentsStr + childrenStr + branchesStr + tagsStr,
                 itm.data(0, self.__subjectRole),
                 messageStr,
+                itm.data(0, self.__fullCommitIdRole).strip(),
             )
         else:
             html = ""
