@@ -21,13 +21,13 @@ from PyQt6.QtWidgets import (
     QLineEdit,
 )
 
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverrideCursorProcess
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursorProcess
 
 from .Ui_GitStashBrowserDialog import Ui_GitStashBrowserDialog
 
-import Preferences
-from Globals import strToQByteArray
+from eric7 import Preferences
+from eric7.Globals import strToQByteArray
 
 
 class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
