@@ -24,10 +24,10 @@ from PyQt6.QtWidgets import (
     QInputDialog,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
-from Globals import strToQByteArray
+from eric7.Globals import strToQByteArray
 
 from .Ui_GitStatusDialog import Ui_GitStatusDialog
 
@@ -35,9 +35,8 @@ from .GitDiffHighlighter import GitDiffHighlighter
 from .GitDiffGenerator import GitDiffGenerator
 from .GitDiffParser import GitDiffParser
 
-import Preferences
-import UI.PixmapCache
-import Utilities
+from eric7 import Preferences, Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class GitStatusDialog(QWidget, Ui_GitStatusDialog):
@@ -104,34 +103,34 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
 
         self.__lDiffMenu = QMenu()
         self.__stageLinesAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"),
+            EricPixmapCache.getIcon("vcsAdd"),
             self.tr("Stage Selected Lines"),
             self.__stageHunkOrLines,
         )
         self.__revertLinesAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert Selected Lines"),
             self.__revertHunkOrLines,
         )
         self.__stageHunkAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"),
+            EricPixmapCache.getIcon("vcsAdd"),
             self.tr("Stage Hunk"),
             self.__stageHunkOrLines,
         )
         self.__revertHunkAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert Hunk"),
             self.__revertHunkOrLines,
         )
 
         self.__rDiffMenu = QMenu()
         self.__unstageLinesAct = self.__rDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Unstage Selected Lines"),
             self.__unstageHunkOrLines,
         )
         self.__unstageHunkAct = self.__rDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Unstage Hunk"),
             self.__unstageHunkOrLines,
         )
@@ -278,7 +277,7 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
         )
         act.setToolTip(self.tr("Adjusts the width of all columns to their contents"))
 
-        self.actionsButton.setIcon(UI.PixmapCache.getIcon("actionsToolButton"))
+        self.actionsButton.setIcon(EricPixmapCache.getIcon("actionsToolButton"))
         self.actionsButton.setMenu(self.__actionsMenu)
 
     def closeEvent(self, e):
@@ -377,7 +376,7 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
         if status in self.ConflictStates:
             itm.setIcon(
                 self.__statusWorkColumn,
-                UI.PixmapCache.getIcon(
+                EricPixmapCache.getIcon(
                     os.path.join("VcsPlugins", "vcsGit", "icons", "conflict.svg")
                 ),
             )
