@@ -12,14 +12,15 @@ import pathlib
 
 from PyQt6.QtWidgets import QMenu, QInputDialog, QToolBar
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-from VCS.ProjectHelper import VcsProjectHelper
+from eric7.VCS.ProjectHelper import VcsProjectHelper
 
-from EricGui.EricAction import EricAction
+from eric7.EricGui.EricAction import EricAction
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Config
 
 
 class GitProjectHelper(VcsProjectHelper):
@@ -71,7 +72,7 @@ class GitProjectHelper(VcsProjectHelper):
         """
         self.vcsNewAct = EricAction(
             self.tr("New from repository"),
-            UI.PixmapCache.getIcon("vcsCheckout"),
+            EricPixmapCache.getIcon("vcsCheckout"),
             self.tr("&New from repository..."),
             0,
             0,
@@ -93,7 +94,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitFetchAct = EricAction(
             self.tr("Fetch changes"),
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Fetch changes"),
             0,
             0,
@@ -113,7 +114,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitPullAct = EricAction(
             self.tr("Pull changes"),
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Pull changes"),
             0,
             0,
@@ -135,7 +136,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsCommitAct = EricAction(
             self.tr("Commit changes to repository"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             0,
             0,
@@ -157,7 +158,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitPushAct = EricAction(
             self.tr("Push changes"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Push changes"),
             0,
             0,
@@ -177,7 +178,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsExportAct = EricAction(
             self.tr("Export from repository"),
-            UI.PixmapCache.getIcon("vcsExport"),
+            EricPixmapCache.getIcon("vcsExport"),
             self.tr("&Export from repository..."),
             0,
             0,
@@ -196,7 +197,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitLogBrowserAct = EricAction(
             self.tr("Show log browser"),
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             0,
             0,
@@ -219,7 +220,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitReflogBrowserAct = EricAction(
             self.tr("Show reflog browser"),
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show reflog browser"),
             0,
             0,
@@ -242,7 +243,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsDiffAct = EricAction(
             self.tr("Show differences"),
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show &differences..."),
             0,
             0,
@@ -264,7 +265,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitExtDiffAct = EricAction(
             self.tr("Show differences (extended)"),
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended) ..."),
             0,
             0,
@@ -286,7 +287,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsStatusAct = EricAction(
             self.tr("Show status"),
-            UI.PixmapCache.getIcon("vcsStatus"),
+            EricPixmapCache.getIcon("vcsStatus"),
             self.tr("Show &status..."),
             0,
             0,
@@ -305,7 +306,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsSwitchAct = EricAction(
             self.tr("Switch"),
-            UI.PixmapCache.getIcon("vcsSwitch"),
+            EricPixmapCache.getIcon("vcsSwitch"),
             self.tr("S&witch..."),
             0,
             0,
@@ -327,7 +328,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsTagAct = EricAction(
             self.tr("Tag in repository"),
-            UI.PixmapCache.getIcon("vcsTag"),
+            EricPixmapCache.getIcon("vcsTag"),
             self.tr("&Tag in repository..."),
             0,
             0,
@@ -440,7 +441,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitBranchAct = EricAction(
             self.tr("Branch in repository"),
-            UI.PixmapCache.getIcon("vcsBranch"),
+            EricPixmapCache.getIcon("vcsBranch"),
             self.tr("&Branch in repository..."),
             0,
             0,
@@ -502,7 +503,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsRevertAct = EricAction(
             self.tr("Revert changes"),
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Re&vert changes"),
             0,
             0,
@@ -523,7 +524,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitUnstageAct = EricAction(
             self.tr("Unstage changes"),
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("&Unstage changes"),
             0,
             0,
@@ -544,7 +545,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.vcsMergeAct = EricAction(
             self.tr("Merge"),
-            UI.PixmapCache.getIcon("vcsMerge"),
+            EricPixmapCache.getIcon("vcsMerge"),
             self.tr("Mer&ge changes..."),
             0,
             0,
@@ -782,7 +783,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitCherryPickAct = EricAction(
             self.tr("Copy Commits"),
-            UI.PixmapCache.getIcon("vcsGraft"),
+            EricPixmapCache.getIcon("vcsGraft"),
             self.tr("Copy Commits"),
             0,
             0,
@@ -1367,7 +1368,7 @@ class GitProjectHelper(VcsProjectHelper):
 
         self.gitBisectLogBrowserAct = EricAction(
             self.tr("Show bisect log browser"),
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show bisect log browser"),
             0,
             0,
@@ -1790,7 +1791,7 @@ class GitProjectHelper(VcsProjectHelper):
         self.subMenus.append(bisectMenu)
 
         tagsMenu = QMenu(self.tr("Tags"), menu)
-        tagsMenu.setIcon(UI.PixmapCache.getIcon("vcsTag"))
+        tagsMenu.setIcon(EricPixmapCache.getIcon("vcsTag"))
         tagsMenu.setTearOffEnabled(True)
         tagsMenu.addAction(self.vcsTagAct)
         tagsMenu.addAction(self.gitTagListAct)
@@ -1798,7 +1799,7 @@ class GitProjectHelper(VcsProjectHelper):
         self.subMenus.append(tagsMenu)
 
         branchesMenu = QMenu(self.tr("Branches"), menu)
-        branchesMenu.setIcon(UI.PixmapCache.getIcon("vcsBranch"))
+        branchesMenu.setIcon(EricPixmapCache.getIcon("vcsBranch"))
         branchesMenu.setTearOffEnabled(True)
         branchesMenu.addAction(self.gitBranchAct)
         branchesMenu.addSeparator()
@@ -1831,7 +1832,7 @@ class GitProjectHelper(VcsProjectHelper):
         remotesMenu.addAction(self.gitRemotePruneAct)
 
         cherrypickMenu = QMenu(self.tr("Cherry-pick"), menu)
-        cherrypickMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft"))
+        cherrypickMenu.setIcon(EricPixmapCache.getIcon("vcsGraft"))
         cherrypickMenu.setTearOffEnabled(True)
         cherrypickMenu.addAction(self.gitCherryPickAct)
         cherrypickMenu.addAction(self.gitCherryPickContinueAct)
@@ -1873,7 +1874,7 @@ class GitProjectHelper(VcsProjectHelper):
         submodulesMenu.addAction(self.gitSubmodulesSummaryAct)
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")
             ),
             self.vcs.vcsName(),
@@ -1936,7 +1937,7 @@ class GitProjectHelper(VcsProjectHelper):
             (EricToolBarManager)
         """
         self.__toolbar = QToolBar(self.tr("Git"), ui)
-        self.__toolbar.setIconSize(UI.Config.ToolBarIconSize)
+        self.__toolbar.setIconSize(Config.ToolBarIconSize)
         self.__toolbar.setObjectName("GitToolbar")
         self.__toolbar.setToolTip(self.tr("Git"))
 
