@@ -20,16 +20,16 @@ from PyQt6.QtWidgets import (
     QTreeWidgetItem,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_HgStatusDialog import Ui_HgStatusDialog
 
 from .HgDiffHighlighter import HgDiffHighlighter
 from .HgDiffGenerator import HgDiffGenerator
 
-import Preferences
-import UI.PixmapCache
+from eric7 import Preferences
+from eric7.EricGui import EricPixmapCache
 
 
 class HgStatusDialog(QWidget, Ui_HgStatusDialog):
@@ -217,7 +217,7 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         )
         act.setToolTip(self.tr("Adjusts the width of all columns to their contents"))
 
-        self.actionsButton.setIcon(UI.PixmapCache.getIcon("actionsToolButton"))
+        self.actionsButton.setIcon(EricPixmapCache.getIcon("actionsToolButton"))
         self.actionsButton.setMenu(self.__actionsMenu)
 
     def closeEvent(self, e):
