@@ -9,8 +9,8 @@ Module implementing the queues extension project helper.
 
 from PyQt6.QtWidgets import QMenu
 
-from EricGui.EricAction import EricAction
-from EricWidgets import EricMessageBox
+from eric7.EricGui.EricAction import EricAction
+from eric7.EricWidgets import EricMessageBox
 
 from ..HgExtensionProjectHelper import HgExtensionProjectHelper
 
