@@ -9,7 +9,7 @@ Module implementing the queues extension interface.
 
 from PyQt6.QtWidgets import QDialog, QApplication, QInputDialog
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from ..HgExtension import HgExtension
 from ..HgDialog import HgDialog
