@@ -13,13 +13,13 @@ import pysvn
 
 from PyQt6.QtWidgets import QMenu
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-from VCS.ProjectBrowserHelper import VcsProjectBrowserHelper
+from eric7.VCS.ProjectBrowserHelper import VcsProjectBrowserHelper
 
-from Project.ProjectBrowserModel import ProjectBrowserFileItem
+from eric7.Project.ProjectBrowserModel import ProjectBrowserFileItem
 
-import UI.PixmapCache
+from eric7.EricGui import EricPixmapCache
 
 
 class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
@@ -213,7 +213,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")
             ),
             self.vcs.vcsName(),
@@ -225,31 +225,33 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Update from repository"),
             self._VCSUpdate,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddMenuActions.append(act)
         if 1 in self.browser.specialMenuEntries:
             self.vcsMenuAddTree = menu.addAction(
-                UI.PixmapCache.getIcon("vcsAdd"),
+                EricPixmapCache.getIcon("vcsAdd"),
                 self.tr("Add tree to repository"),
                 self._VCSAddTree,
             )
             self.vcsAddMenuActions.append(self.vcsMenuAddTree)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
@@ -271,49 +273,51 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             self._VCSLogBrowser,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRepo"),
+            EricPixmapCache.getIcon("vcsRepo"),
             self.tr("Show repository info"),
             self.__SVNInfo,
         )
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff"),
+            EricPixmapCache.getIcon("vcsSbsDiff"),
             self.tr("Show differences side-by-side"),
             self.__SVNSbsDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__SVNExtendedDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff"),
+            EricPixmapCache.getIcon("vcsSbsDiff"),
             self.tr("Show differences side-by-side (extended)"),
             self.__SVNSbsExtendedDiff,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (URLs)"),
             self.__SVNUrlDiff,
         )
@@ -322,34 +326,36 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions.append(self.blameAct)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self._VCSRevert,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsMerge"), self.tr("Merge changes"), self._VCSMerge
+            EricPixmapCache.getIcon("vcsMerge"),
+            self.tr("Merge changes"),
+            self._VCSMerge,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(self.tr("Conflicts resolved"), self.__SVNResolve)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLock"), self.tr("Lock"), self.__SVNLock
+            EricPixmapCache.getIcon("vcsLock"), self.tr("Lock"), self.__SVNLock
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock"), self.tr("Unlock"), self.__SVNUnlock
+            EricPixmapCache.getIcon("vcsUnlock"), self.tr("Unlock"), self.__SVNUnlock
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock"),
+            EricPixmapCache.getIcon("vcsUnlock"),
             self.tr("Break Lock"),
             self.__SVNBreakLock,
         )
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock"),
+            EricPixmapCache.getIcon("vcsUnlock"),
             self.tr("Steal Lock"),
             self.__SVNStealLock,
         )
@@ -396,7 +402,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")
             ),
             self.vcs.vcsName(),
@@ -408,31 +414,33 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Update from repository"),
             self._VCSUpdate,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddMultiMenuActions.append(act)
         if 1 in self.browser.specialMenuEntries:
             self.vcsMultiMenuAddTree = menu.addAction(
-                UI.PixmapCache.getIcon("vcsAdd"),
+                EricPixmapCache.getIcon("vcsAdd"),
                 self.tr("Add tree to repository"),
                 self._VCSAddTree,
             )
             self.vcsAddMultiMenuActions.append(self.vcsMultiMenuAddTree)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
@@ -449,31 +457,33 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__SVNExtendedDiff,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (URLs)"),
             self.__SVNUrlDiff,
         )
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self._VCSRevert,
         )
@@ -482,21 +492,21 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLock"), self.tr("Lock"), self.__SVNLock
+            EricPixmapCache.getIcon("vcsLock"), self.tr("Lock"), self.__SVNLock
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock"), self.tr("Unlock"), self.__SVNUnlock
+            EricPixmapCache.getIcon("vcsUnlock"), self.tr("Unlock"), self.__SVNUnlock
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock"),
+            EricPixmapCache.getIcon("vcsUnlock"),
             self.tr("Break Lock"),
             self.__SVNBreakLock,
         )
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock"),
+            EricPixmapCache.getIcon("vcsUnlock"),
             self.tr("Steal Lock"),
             self.__SVNStealLock,
         )
@@ -539,7 +549,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")
             ),
             self.vcs.vcsName(),
@@ -586,7 +596,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")
             ),
             self.vcs.vcsName(),
@@ -598,24 +608,26 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Update from repository"),
             self._VCSUpdate,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
@@ -637,50 +649,54 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog"),
+            EricPixmapCache.getIcon("vcsLog"),
             self.tr("Show log browser"),
             self._VCSLogBrowser,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRepo"),
+            EricPixmapCache.getIcon("vcsRepo"),
             self.tr("Show repository info"),
             self.__SVNInfo,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__SVNExtendedDiff,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (URLs)"),
             self.__SVNUrlDiff,
         )
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self._VCSRevert,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsMerge"), self.tr("Merge changes"), self._VCSMerge
+            EricPixmapCache.getIcon("vcsMerge"),
+            self.tr("Merge changes"),
+            self._VCSMerge,
         )
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(self.tr("Conflicts resolved"), self.__SVNResolve)
@@ -729,7 +745,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon(
+            EricPixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")
             ),
             self.vcs.vcsName(),
@@ -741,24 +757,26 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate"),
+            EricPixmapCache.getIcon("vcsUpdate"),
             self.tr("Update from repository"),
             self._VCSUpdate,
         )
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             self.tr("Commit changes to repository..."),
             self._VCSCommit,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add to repository"), self._VCSAdd
+            EricPixmapCache.getIcon("vcsAdd"),
+            self.tr("Add to repository"),
+            self._VCSAdd,
         )
         self.vcsAddDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove"),
+            EricPixmapCache.getIcon("vcsRemove"),
             self.tr("Remove from repository (and disk)"),
             self._VCSRemove,
         )
@@ -775,37 +793,41 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus"), self.tr("Show status"), self._VCSStatus
+            EricPixmapCache.getIcon("vcsStatus"),
+            self.tr("Show status"),
+            self._VCSStatus,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences"),
             self._VCSDiff,
         )
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (extended)"),
             self.__SVNExtendedDiff,
         )
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"),
+            EricPixmapCache.getIcon("vcsDiff"),
             self.tr("Show differences (URLs)"),
             self.__SVNUrlDiff,
         )
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"),
+            EricPixmapCache.getIcon("vcsRevert"),
             self.tr("Revert changes"),
             self._VCSRevert,
         )
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsMerge"), self.tr("Merge changes"), self._VCSMerge
+            EricPixmapCache.getIcon("vcsMerge"),
+            self.tr("Merge changes"),
+            self._VCSMerge,
         )
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(self.tr("Conflicts resolved"), self.__SVNResolve)
