@@ -17,18 +17,17 @@ from PyQt6.QtCore import QDateTime, Qt, pyqtSlot
 from PyQt6.QtGui import QTextCursor
 from PyQt6.QtWidgets import QWidget, QDialogButtonBox
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
-from EricUtilities.EricMutexLocker import EricMutexLocker
+from eric7.EricUtilities.EricMutexLocker import EricMutexLocker
 
 from .SvnDialogMixin import SvnDialogMixin
 from .Ui_SvnDiffDialog import Ui_SvnDiffDialog
 from .SvnDiffHighlighter import SvnDiffHighlighter
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
