@@ -20,14 +20,14 @@ from PyQt6.QtWidgets import (
     QTreeWidgetItem,
 )
 
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverrideCursorProcess
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursorProcess
 
 from .Ui_SvnLogBrowserDialog import Ui_SvnLogBrowserDialog
 
-import Preferences
-import UI.PixmapCache
-from Globals import strToQByteArray
+from eric7 import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7.Globals import strToQByteArray
 
 
 class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
@@ -50,8 +50,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.buttonBox.button(QDialogButtonBox.StandardButton.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.StandardButton.Cancel).setDefault(True)
 
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+        self.upButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(EricPixmapCache.getIcon("1downarrow"))
 
         self.filesTree.headerItem().setText(self.filesTree.columnCount(), "")
         self.filesTree.header().setSortIndicator(0, Qt.SortOrder.AscendingOrder)
