@@ -22,13 +22,13 @@ from PyQt6.QtWidgets import (
     QTreeWidgetItem,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_SvnStatusDialog import Ui_SvnStatusDialog
 
-import Preferences
-from Globals import strToQByteArray
+from eric7 import Preferences
+from eric7.Globals import strToQByteArray
 
 
 class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
