@@ -20,16 +20,15 @@ from PyQt6.QtWidgets import (
     QApplication,
 )
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
-from ViewManager.ViewManager import ViewManager
+from eric7.ViewManager.ViewManager import ViewManager
 
-import QScintilla.Editor
-from QScintilla.Editor import Editor
-from QScintilla.EditorAssembly import EditorAssembly
+from eric7.QScintilla.Editor import Editor
+from eric7.QScintilla.EditorAssembly import EditorAssembly
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences
 
 
 class StackedWidget(QStackedWidget):
@@ -67,7 +66,7 @@ class StackedWidget(QStackedWidget):
         @param widget widget to be removed
         @type QWidget
         """
-        if isinstance(widget, QScintilla.Editor.Editor):
+        if isinstance(widget, Editor):
             self.editors.remove(widget)
             widget = widget.parent()
         super().removeWidget(widget)
@@ -92,7 +91,7 @@ class StackedWidget(QStackedWidget):
         @type QWidget
         """
         if widget is not None:
-            if isinstance(widget, QScintilla.Editor.Editor):
+            if isinstance(widget, Editor):
                 self.editors.remove(widget)
                 self.editors.insert(0, widget)
                 widget = widget.parent()
@@ -264,49 +263,49 @@ class Listspace(ViewManager):
         """
         self.__startMenu = QMenu(self.tr("Start"), self)
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("runScript"),
+            EricPixmapCache.getIcon("runScript"),
             self.tr("Run Script..."),
             self.__contextMenuRunScript,
         )
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("debugScript"),
+            EricPixmapCache.getIcon("debugScript"),
             self.tr("Debug Script..."),
             self.__contextMenuDebugScript,
         )
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("profileScript"),
+            EricPixmapCache.getIcon("profileScript"),
             self.tr("Profile Script..."),
             self.__contextMenuProfileScript,
         )
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("coverageScript"),
+            EricPixmapCache.getIcon("coverageScript"),
             self.tr("Coverage run of Script..."),
             self.__contextMenuCoverageScript,
         )
 
         self.__menu = QMenu(self)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("tabClose"),
+            EricPixmapCache.getIcon("tabClose"),
             self.tr("Close"),
             self.__contextMenuClose,
         )
         self.closeOthersMenuAct = self.__menu.addAction(
-            UI.PixmapCache.getIcon("tabCloseOther"),
+            EricPixmapCache.getIcon("tabCloseOther"),
             self.tr("Close Others"),
             self.__contextMenuCloseOthers,
         )
         self.__menu.addAction(self.tr("Close All"), self.__contextMenuCloseAll)
         self.__menu.addSeparator()
         self.saveMenuAct = self.__menu.addAction(
-            UI.PixmapCache.getIcon("fileSave"), self.tr("Save"), self.__contextMenuSave
+            EricPixmapCache.getIcon("fileSave"), self.tr("Save"), self.__contextMenuSave
         )
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("fileSaveAs"),
+            EricPixmapCache.getIcon("fileSaveAs"),
             self.tr("Save As..."),
             self.__contextMenuSaveAs,
         )
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("fileSaveAll"),
+            EricPixmapCache.getIcon("fileSaveAll"),
             self.tr("Save All"),
             self.__contextMenuSaveAll,
         )
@@ -318,12 +317,12 @@ class Listspace(ViewManager):
         self.__startAct = self.__menu.addMenu(self.__startMenu)
         self.__menu.addSeparator()
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("printPreview"),
+            EricPixmapCache.getIcon("printPreview"),
             self.tr("Print Preview"),
             self.__contextMenuPrintPreviewFile,
         )
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("print"),
+            EricPixmapCache.getIcon("print"),
             self.tr("Print"),
             self.__contextMenuPrintFile,
         )
@@ -658,7 +657,7 @@ class Listspace(ViewManager):
             keys.append("empty")
         item = self.viewlist.item(index)
         if item:
-            item.setIcon(UI.PixmapCache.getCombinedIcon(keys))
+            item.setIcon(EricPixmapCache.getCombinedIcon(keys))
         self.viewlist.setCurrentRow(currentRow)
         self._checkActions(editor)
 
@@ -682,7 +681,7 @@ class Listspace(ViewManager):
             keys.append("empty")
         item = self.viewlist.item(index)
         if item:
-            item.setIcon(UI.PixmapCache.getCombinedIcon(keys))
+            item.setIcon(EricPixmapCache.getCombinedIcon(keys))
         self.viewlist.setCurrentRow(currentRow)
 
         ViewManager._syntaxErrorToggled(self, editor)
@@ -1001,7 +1000,7 @@ class Listspace(ViewManager):
             if isinstance(watched, QStackedWidget):
                 switched = watched is not self.currentStack
                 self.currentStack = watched
-            elif isinstance(watched, QScintilla.Editor.Editor):
+            elif isinstance(watched, Editor):
                 for stack in self.stacks:
                     if stack.hasEditor(watched):
                         switched = stack is not self.currentStack
