@@ -46,7 +46,7 @@ from eric7.EricWidgets.EricLed import EricLed
 from eric7 import Preferences
 from eric7.Globals import isMacPlatform
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class TabBar(EricWheelTabBar):
