@@ -12,7 +12,7 @@ import os
 from PyQt6.QtCore import pyqtSlot
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QAbstractButton
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_EricMessageBoxWizardDialog import Ui_EricMessageBoxWizardDialog
 
@@ -428,7 +428,7 @@ class EricMessageBoxWizardDialog(QDialog, Ui_EricMessageBoxWizardDialog):
         if len(buttons) == 0:
             return ""
 
-        joinstring = " |{0}{1}".format(os.linesep, istring)
+        joinstring = "{0}{1}| ".format(os.linesep, istring)
         intro = "," if withIntro else ""
         btnCode = "{0}{1}{2}{3}".format(
             intro, os.linesep, istring, joinstring.join(buttons)
@@ -568,5 +568,5 @@ class EricMessageBoxWizardDialog(QDialog, Ui_EricMessageBoxWizardDialog):
             if not self.parentNone.isChecked():
                 msgdlg += ",{0}{1}parent={2}".format(os.linesep, istring, parent)
 
-        msgdlg += "{0}){0}".format(estring)
+        msgdlg += ",{0}){0}".format(estring)
         return msgdlg
