@@ -12,7 +12,7 @@ import os
 from PyQt6.QtCore import pyqtSlot, QCoreApplication, QUrl
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QFileDialog, QButtonGroup
 
-from EricWidgets.EricCompleters import EricFileCompleter, EricDirCompleter
+from eric7.EricWidgets.EricCompleters import EricFileCompleter, EricDirCompleter
 
 from .Ui_FileDialogWizardDialog import Ui_FileDialogWizardDialog
 
@@ -472,7 +472,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 code += ",{0}{1}{2}".format(
                     os.linesep, istring, self.__prepareSchemesList()
                 )
-            code += "{0}){0}".format(estring)
+            code += ",{0}){0}".format(estring)
         elif (
             self.rOpenFiles.isChecked()
             or self.rfOpenFiles.isChecked()
@@ -548,7 +548,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 code += ",{0}{1}{2}".format(
                     os.linesep, istring, self.__prepareSchemesList()
                 )
-            code += "{0}){0}".format(estring)
+            code += ",{0}){0}".format(estring)
         elif (
             self.rSaveFile.isChecked()
             or self.rfSaveFile.isChecked()
@@ -633,7 +633,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                     os.linesep, istring, self.__prepareSchemesList()
                 )
 
-            code += "{0}){0}".format(estring)
+            code += ",{0}){0}".format(estring)
         elif self.rDirectory.isChecked() or self.rDirectoryUrl.isChecked():
             if self.rDirectory.isChecked():
                 method = (
@@ -683,7 +683,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 code += ",{0}{1}{2}".format(
                     os.linesep, istring, self.__prepareSchemesList()
                 )
-            code += "{0}){0}".format(estring)
+            code += ",{0}){0}".format(estring)
 
         return code
 
