@@ -20,16 +20,15 @@ import trove_classifiers
 from PyQt6.QtCore import pyqtSlot, Qt
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QTreeWidgetItem, QListWidgetItem
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricFileDialog
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricFileDialog
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .AddEntryPointDialog import AddEntryPointDialog
 from .AddProjectUrlDialog import AddProjectUrlDialog
 from .Ui_SetupWizardDialog import Ui_SetupWizardDialog
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
@@ -363,7 +362,7 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         platforms = self.platformsEdit.toPlainText().splitlines()
         if platforms:
             sourceCode += "{0}platforms=[{1}".format(istring, os.linesep)
-            sourceCode += '{0}"{1}"{2}'.format(
+            sourceCode += '{0}"{1}",{2}'.format(
                 i1string,
                 '",{0}{1}"'.format(os.linesep, i1string).join(platforms),
                 os.linesep,
@@ -384,7 +383,7 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         classifiers = [c for c in classifiers if bool(c)]
         if classifiers:
             sourceCode += "{0}classifiers=[{1}".format(istring, os.linesep)
-            sourceCode += '{0}"{1}"{2}'.format(
+            sourceCode += '{0}"{1}",{2}'.format(
                 i1string,
                 '",{0}{1}"'.format(os.linesep, i1string).join(classifiers),
                 os.linesep,
@@ -415,7 +414,7 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
                 sourceCode += "{0}{1}".format(os.linesep, istring)
         if excludePatterns:
             sourceCode += "{0}{1}exclude=[{0}".format(os.linesep, i1string)
-            sourceCode += '{0}"{1}"{2}'.format(
+            sourceCode += '{0}"{1}",{2}'.format(
                 i2string,
                 '",{0}{1}"'.format(os.linesep, i2string).join(excludePatterns),
                 os.linesep,
@@ -433,7 +432,7 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
             modules.append(self.modulesList.item(row).text())
         if modules:
             sourceCode += "{0}py_modules=[{1}".format(istring, os.linesep)
-            sourceCode += '{0}"{1}"{2}'.format(
+            sourceCode += '{0}"{1}",{2}'.format(
                 i1string,
                 '",{0}{1}"'.format(os.linesep, i1string).join(modules),
                 os.linesep,
