@@ -44,7 +44,7 @@ from eric7 import Preferences
 
 from eric7.EricGui import EricPixmapCache
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class ConfigurationPageItem(QTreeWidgetItem):
