@@ -7,12 +7,12 @@
 Module implementing the Corba configuration page.
 """
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_CorbaPage import Ui_CorbaPage
 
-import Preferences
+from eric7 import Preferences
 
 
 class CorbaPage(ConfigurationPageBase, Ui_CorbaPage):
