@@ -7,10 +7,12 @@
 Module implementing the Jedi Calltips configuration page.
 """
 
-from Preferences.ConfigurationPages.ConfigurationPageBase import ConfigurationPageBase
+from eric7.Preferences.ConfigurationPages.ConfigurationPageBase import (
+    ConfigurationPageBase,
+)
 from .Ui_EditorCallTipsJediPage import Ui_EditorCallTipsJediPage
 
-import Preferences
+from eric7 import Preferences
 
 
 class EditorCallTipsJediPage(ConfigurationPageBase, Ui_EditorCallTipsJediPage):
