@@ -540,7 +540,7 @@ class EditorHighlightingStylesPage(
             (defaults to False)
         @type bool (optional)
         """
-        from eric7config import getConfig
+        from eric7.Globals import getConfig
 
         stylesDir = getConfig("ericStylesDir")
 
@@ -610,7 +610,7 @@ class EditorHighlightingStylesPage(
             (defaults to False)
         @type bool (optional)
         """
-        from eric7config import getConfig
+        from eric7.Globals import getConfig
 
         stylesDir = getConfig("ericStylesDir")
 
