@@ -10,7 +10,7 @@ Module implementing the Editor Mouse Click Handlers configuration page.
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorMouseClickHandlerPage import Ui_EditorMouseClickHandlerPage
 
-import Preferences
+from eric7 import Preferences
 
 
 class EditorMouseClickHandlerPage(
