@@ -12,7 +12,7 @@ from PyQt6.Qsci import QsciLexerPython
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorPropertiesPage import Ui_EditorPropertiesPage
 
-import Preferences
+from eric7 import Preferences
 
 
 class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
