@@ -15,7 +15,7 @@ from PyQt6.Qsci import QsciScintilla
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorStylesPage import Ui_EditorStylesPage
 
-import Preferences
+from eric7 import Preferences
 
 
 class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
@@ -31,7 +31,7 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         self.setupUi(self)
         self.setObjectName("EditorStylesPage")
 
-        from QScintilla.QsciScintillaCompat import QsciScintillaCompat
+        from eric7.QScintilla.QsciScintillaCompat import QsciScintillaCompat
 
         self.foldStyles = [
             QsciScintilla.FoldStyle.PlainFoldStyle.value,
