@@ -20,7 +20,7 @@ from .Ui_IconsPage import Ui_IconsPage
 
 from eric7 import Preferences
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class IconsPage(ConfigurationPageBase, Ui_IconsPage):
