@@ -21,7 +21,7 @@ from .Ui_InterfaceLightPage import Ui_InterfaceLightPage
 
 from eric7 import Preferences, Utilities
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class InterfaceLightPage(ConfigurationPageBase, Ui_InterfaceLightPage):
