@@ -23,7 +23,7 @@ from .Ui_InterfacePage import Ui_InterfacePage
 from eric7 import Preferences, Utilities
 from eric7.EricGui import EricPixmapCache
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
