@@ -10,7 +10,7 @@ Module implementing the Project configuration page.
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_ProjectPage import Ui_ProjectPage
 
-import Preferences
+from eric7 import Preferences
 
 
 class ProjectPage(ConfigurationPageBase, Ui_ProjectPage):
