@@ -12,11 +12,10 @@ from PyQt6.QtCore import pyqtSlot, QLocale
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_WebBrowserPage import Ui_WebBrowserPage
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences
 
 
-# TODO: add a combo box selection for 'AcceptFileSystemAccessRequest'
 class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
     """
     Class implementing the  Web Browser configuration page.
@@ -183,7 +182,8 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
                 engineName
             ) in self.__browserWindow.imageSearchEngine().searchEngineNames():
                 self.imageSearchComboBox.addItem(
-                    UI.PixmapCache.getIcon("{0}".format(engineName.lower())), engineName
+                    EricPixmapCache.getIcon("{0}".format(engineName.lower())),
+                    engineName,
                 )
             index = self.imageSearchComboBox.findText(
                 Preferences.getWebBrowser("ImageSearchEngine")
@@ -228,6 +228,9 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         self.requestQuotaComboBox.setCurrentIndex(
             Preferences.getWebBrowser("AcceptQuotaRequest")
         )
+        self.fileSystemAccessComboBox.setCurrentIndex(
+            Preferences.getWebBrowser("AcceptFileSystemAccessRequest")
+        )
 
     def save(self):
         """
@@ -397,6 +400,10 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         Preferences.setWebBrowser(
             "AcceptQuotaRequest", self.requestQuotaComboBox.currentIndex()
         )
+        Preferences.setWebBrowser(
+            "AcceptFileSystemAccessRequest",
+            self.fileSystemAccessComboBox.currentIndex(),
+        )
 
     @pyqtSlot()
     def on_setCurrentPageButton_clicked(self):
@@ -436,7 +443,7 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         """
         Private slot to edit the referer whitelist.
         """
-        from WebBrowser.Network.SendRefererWhitelistDialog import (
+        from eric7.WebBrowser.Network.SendRefererWhitelistDialog import (
             SendRefererWhitelistDialog,
         )
 
