@@ -19,14 +19,12 @@ from PyQt6.QtWidgets import (
     QDialogButtonBox,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
 from .Ui_ProgramsDialog import Ui_ProgramsDialog
 
-import Globals
-import Preferences
-import Utilities
+from eric7 import Globals, Preferences, Utilities
 
 
 class ProgramsDialog(QDialog, Ui_ProgramsDialog):
