@@ -17,7 +17,7 @@ from eric7.EricWidgets import EricMessageBox, EricFileDialog
 
 from eric7 import Globals, Preferences
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class ThemeManager(QObject):
