@@ -30,7 +30,7 @@ from eric7.EricWidgets import EricMessageBox
 from .Ui_CreateDialogCodeDialog import Ui_CreateDialogCodeDialog
 from .NewDialogClassDialog import NewDialogClassDialog
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 from eric7 import Globals, Preferences
 
