@@ -19,7 +19,7 @@ from eric7.EricWidgets.EricApplication import ericApp
 from .Ui_DebuggerPropertiesDialog import Ui_DebuggerPropertiesDialog
 
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 from eric7 import Preferences
 from eric7.EricGui import EricPixmapCache
