@@ -21,12 +21,12 @@ from PyQt6.QtCore import (
 )
 from PyQt6.QtWidgets import QTreeView, QApplication, QMenu, QDialog, QAbstractItemView
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
-from UI.Browser import Browser
-from UI.BrowserModel import BrowserDirectoryItem, BrowserFileItem
+from eric7.UI.Browser import Browser
+from eric7.UI.BrowserModel import BrowserDirectoryItem, BrowserFileItem
 
 from .ProjectBrowserModel import (
     ProjectBrowserSimpleDirectoryItem,
@@ -306,7 +306,7 @@ class ProjectBaseBrowser(Browser):
             dn = self.project.getRelativePath(dn)
             dirs.append(dn)
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
