@@ -14,18 +14,17 @@ import contextlib
 from PyQt6.QtCore import QDir, QModelIndex, pyqtSignal, QFileSystemWatcher, Qt
 from PyQt6.QtGui import QColor
 
-from UI.BrowserModel import (
+from eric7.UI.BrowserModel import (
     BrowserModel,
     BrowserItem,
     BrowserDirectoryItem,
     BrowserFileItem,
 )
 
-import UI.PixmapCache
-import Preferences
-import Utilities
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences, Utilities
 
-import Utilities.ModuleParser
+from eric7.Utilities import ModuleParser
 
 ProjectBrowserItemSimpleDirectory = 100
 ProjectBrowserItemDirectory = 101
@@ -136,9 +135,9 @@ class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
         self.type_ = ProjectBrowserItemSimpleDirectory
         if os.path.lexists(self._dirName) and os.path.islink(self._dirName):
             self.symlink = True
-            self.icon = UI.PixmapCache.getSymlinkIcon("dirClosed")
+            self.icon = EricPixmapCache.getSymlinkIcon("dirClosed")
         else:
-            self.icon = UI.PixmapCache.getIcon("dirClosed")
+            self.icon = EricPixmapCache.getIcon("dirClosed")
 
     def setName(self, dinfo, full=True):
         """
@@ -420,7 +419,7 @@ class ProjectBrowserModel(BrowserModel):
         self.endResetModel()
 
         # reset the module parser cache
-        Utilities.ModuleParser.resetParsedModules()
+        ModuleParser.resetParsedModules()
 
     def projectOpened(self):
         """
@@ -860,9 +859,7 @@ class ProjectBrowserModel(BrowserModel):
                 self.beginRemoveRows(index, 0, itm.childCount() - 1)
                 itm.removeChildren()
                 self.endRemoveRows()
-            Utilities.ModuleParser.resetParsedModule(
-                os.path.join(self.project.ppath, name)
-            )
+            ModuleParser.resetParsedModule(os.path.join(self.project.ppath, name))
 
             self.populateItem(itm, True)
 
