@@ -34,7 +34,7 @@ from eric7.UI.NotificationWidget import NotificationTypes
 
 from eric7 import Preferences, Utilities
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class ProjectFormsBrowser(ProjectBaseBrowser):
