@@ -15,7 +15,7 @@ from PyQt6.QtCore import QModelIndex, pyqtSignal, QUrl
 from PyQt6.QtGui import QDesktopServices
 from PyQt6.QtWidgets import QDialog, QMenu
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .ProjectBrowserModel import (
     ProjectBrowserFileItem,
@@ -25,8 +25,8 @@ from .ProjectBrowserModel import (
 )
 from .ProjectBaseBrowser import ProjectBaseBrowser
 
-import Utilities.MimeTypes
-import Preferences
+from eric7.Utilities import MimeTypes
+from eric7 import Preferences
 
 
 class ProjectOthersBrowser(ProjectBaseBrowser):
@@ -171,20 +171,24 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
             return
 
         with contextlib.suppress(Exception):
-            cnt = self.getSelectedItemsCount([
-                ProjectBrowserFileItem,
-                ProjectBrowserDirectoryItem,
-                ProjectBrowserSimpleDirectoryItem,
-            ])
+            cnt = self.getSelectedItemsCount(
+                [
+                    ProjectBrowserFileItem,
+                    ProjectBrowserDirectoryItem,
+                    ProjectBrowserSimpleDirectoryItem,
+                ]
+            )
             if cnt < 1:
                 index = self.indexAt(coord)
                 if index.isValid():
                     self._selectSingleItem(index)
-                    cnt = self.getSelectedItemsCount([
-                        ProjectBrowserFileItem,
-                        ProjectBrowserDirectoryItem,
-                        ProjectBrowserSimpleDirectoryItem,
-                    ])
+                    cnt = self.getSelectedItemsCount(
+                        [
+                            ProjectBrowserFileItem,
+                            ProjectBrowserDirectoryItem,
+                            ProjectBrowserSimpleDirectoryItem,
+                        ]
+                    )
 
             if cnt > 1:
                 self.multiMenu.popup(self.mapToGlobal(coord))
@@ -297,7 +301,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
                 elif itm.isEricGraphicsFile():
                     self.umlFile.emit(itm.fileName())
                 else:
-                    if Utilities.MimeTypes.isTextFile(itm.fileName()):
+                    if MimeTypes.isTextFile(itm.fileName()):
                         self.sourceFile.emit(itm.fileName())
                     else:
                         QDesktopServices.openUrl(QUrl(itm.fileName()))
@@ -309,9 +313,9 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         itmList = self.getSelectedItems()
 
         for itm in itmList:
-            if isinstance(
-                itm, ProjectBrowserFileItem
-            ) and Utilities.MimeTypes.isTextFile(itm.fileName()):
+            if isinstance(itm, ProjectBrowserFileItem) and MimeTypes.isTextFile(
+                itm.fileName()
+            ):
                 self.sourceFile.emit(itm.fileName())
 
     def __showMimeType(self):
@@ -320,7 +324,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         """
         itmList = self.getSelectedItems()
         if itmList:
-            mimetype = Utilities.MimeTypes.mimeType(itmList[0].fileName())
+            mimetype = MimeTypes.mimeType(itmList[0].fileName())
             if mimetype is None:
                 EricMessageBox.warning(
                     self,
@@ -440,7 +444,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         del dirFullNames
         del dirNames
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
