@@ -13,10 +13,10 @@ import contextlib
 from PyQt6.QtCore import pyqtSignal
 from PyQt6.QtWidgets import QDialog, QInputDialog, QMenu
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-from UI.BrowserModel import (
+from eric7.UI.BrowserModel import (
     BrowserFileItem,
     BrowserClassItem,
     BrowserMethodItem,
@@ -32,10 +32,11 @@ from .ProjectBrowserModel import (
 )
 from .ProjectBaseBrowser import ProjectBaseBrowser
 
-import Utilities
-import UI.PixmapCache
+from eric7 import Utilities
+from eric7.EricGui import EricPixmapCache
 
-from CodeFormatting.BlackFormattingAction import BlackFormattingAction
+from eric7.CodeFormatting.BlackFormattingAction import BlackFormattingAction
+from eric7.CodeFormatting.BlackUtilities import aboutBlack
 
 
 class ProjectSourcesBrowser(ProjectBaseBrowser):
@@ -130,6 +131,10 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         self.checksMenu.aboutToShow.connect(self.__showContextMenuCheck)
 
         self.formattingMenu = QMenu(self.tr("Code Formatting"))
+        act = self.formattingMenu.addAction(self.tr("Black"), aboutBlack)
+        font = act.font()
+        font.setBold(True)
+        act.setFont(font)
         self.formattingMenu.addAction(
             self.tr("Format Code"),
             lambda: self.__performFormatWithBlack(BlackFormattingAction.Format),
@@ -169,7 +174,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         )
         self.graphicsMenu.addSeparator()
         self.graphicsMenu.addAction(
-            UI.PixmapCache.getIcon("open"),
+            EricPixmapCache.getIcon("open"),
             self.tr("Load Diagram..."),
             self.__loadDiagram,
         )
@@ -177,22 +182,22 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
 
         self.__startMenu = QMenu(self.tr("Start"), self)
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("runScript"),
+            EricPixmapCache.getIcon("runScript"),
             self.tr("Run Script..."),
             self.__contextMenuRunScript,
         )
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("debugScript"),
+            EricPixmapCache.getIcon("debugScript"),
             self.tr("Debug Script..."),
             self.__contextMenuDebugScript,
         )
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("profileScript"),
+            EricPixmapCache.getIcon("profileScript"),
             self.tr("Profile Script..."),
             self.__contextMenuProfileScript,
         )
         self.__startMenu.addAction(
-            UI.PixmapCache.getIcon("coverageScript"),
+            EricPixmapCache.getIcon("coverageScript"),
             self.tr("Coverage run of Script..."),
             self.__contextMenuCoverageScript,
         )
@@ -364,7 +369,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         )
         self.graphicsMenu.addSeparator()
         self.graphicsMenu.addAction(
-            UI.PixmapCache.getIcon("fileOpen"),
+            EricPixmapCache.getIcon("fileOpen"),
             self.tr("Load Diagram..."),
             self.__loadDiagram,
         )
@@ -968,7 +973,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             fn = self.project.getRelativePath(fn2)
             files.append(fn)
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
@@ -1003,7 +1008,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         itm = self.model().item(self.currentIndex())
         fn = itm.fileName()
 
-        from DataViews.CodeMetricsDialog import CodeMetricsDialog
+        from eric7.DataViews.CodeMetricsDialog import CodeMetricsDialog
 
         self.codemetrics = CodeMetricsDialog()
         self.codemetrics.show()
@@ -1042,7 +1047,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         else:
             return
 
-        from DataViews.PyCoverageDialog import PyCoverageDialog
+        from eric7.DataViews.PyCoverageDialog import PyCoverageDialog
 
         self.codecoverage = PyCoverageDialog()
         self.codecoverage.show()
@@ -1081,7 +1086,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         else:
             return
 
-        from DataViews.PyProfileDialog import PyProfileDialog
+        from eric7.DataViews.PyProfileDialog import PyProfileDialog
 
         self.profiledata = PyProfileDialog()
         self.profiledata.show()
@@ -1113,7 +1118,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             yesDefault=True,
         )
 
-        from Graphics.UMLDialog import UMLDialog, UMLDialogType
+        from eric7.Graphics.UMLDialog import UMLDialog, UMLDialogType
 
         self.classDiagram = UMLDialog(
             UMLDialogType.CLASS_DIAGRAM, self.project, fn, self, noAttrs=not res
@@ -1136,7 +1141,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             self.tr("""Include imports from external modules?"""),
         )
 
-        from Graphics.UMLDialog import UMLDialog, UMLDialogType
+        from eric7.Graphics.UMLDialog import UMLDialog, UMLDialogType
 
         self.importsDiagram = UMLDialog(
             UMLDialogType.IMPORTS_DIAGRAM,
@@ -1164,7 +1169,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             yesDefault=True,
         )
 
-        from Graphics.UMLDialog import UMLDialog, UMLDialogType
+        from eric7.Graphics.UMLDialog import UMLDialog, UMLDialogType
 
         self.packageDiagram = UMLDialog(
             UMLDialogType.PACKAGE_DIAGRAM, self.project, package, self, noAttrs=not res
@@ -1182,7 +1187,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             yesDefault=True,
         )
 
-        from Graphics.UMLDialog import UMLDialog, UMLDialogType
+        from eric7.Graphics.UMLDialog import UMLDialog, UMLDialogType
 
         self.applicationDiagram = UMLDialog(
             UMLDialogType.APPLICATION_DIAGRAM, self.project, self, noModules=not res
@@ -1193,7 +1198,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         """
         Private slot to load a diagram from file.
         """
-        from Graphics.UMLDialog import UMLDialog, UMLDialogType
+        from eric7.Graphics.UMLDialog import UMLDialog, UMLDialogType
 
         self.loadedDiagram = None
         loadedDiagram = UMLDialog(UMLDialogType.NO_DIAGRAM, self.project, parent=self)
@@ -1259,8 +1264,10 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         @param action formatting operation to be performed
         @type BlackFormattingAction
         """
-        from CodeFormatting.BlackConfigurationDialog import BlackConfigurationDialog
-        from CodeFormatting.BlackFormattingDialog import BlackFormattingDialog
+        from eric7.CodeFormatting.BlackConfigurationDialog import (
+            BlackConfigurationDialog,
+        )
+        from eric7.CodeFormatting.BlackFormattingDialog import BlackFormattingDialog
 
         files = [
             itm.fileName()
