@@ -18,10 +18,10 @@ from PyQt6.QtCore import pyqtSignal, Qt, QProcess, QEventLoop
 from PyQt6.QtGui import QGuiApplication, QCursor
 from PyQt6.QtWidgets import QDialog, QMenu
 
-from EricGui.EricOverrideCursor import EricOverridenCursor
+from eric7.EricGui.EricOverrideCursor import EricOverridenCursor
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .ProjectBrowserModel import (
     ProjectBrowserFileItem,
@@ -31,11 +31,10 @@ from .ProjectBrowserModel import (
 )
 from .ProjectBaseBrowser import ProjectBaseBrowser
 
-import UI.PixmapCache
-from UI.NotificationWidget import NotificationTypes
+from eric7.EricGui import EricPixmapCache
+from eric7.UI.NotificationWidget import NotificationTypes
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class ProjectTranslationsBrowser(ProjectBaseBrowser):
@@ -776,7 +775,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
 
         translationFiles = [itm.fileName() for itm in itmList]
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
@@ -1047,7 +1046,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         ui = ericApp().getObject("UserInterface")
         if exitStatus == QProcess.ExitStatus.NormalExit and exitCode == 0:
             ui.showNotification(
-                UI.PixmapCache.getPixmap("linguist48"),
+                EricPixmapCache.getPixmap("linguist48"),
                 self.tr("Translation file generation"),
                 self.tr(
                     "The generation of the translation files (*.ts)" " was successful."
@@ -1059,7 +1058,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             else:
                 info = ""
             ui.showNotification(
-                UI.PixmapCache.getPixmap("linguist48"),
+                EricPixmapCache.getPixmap("linguist48"),
                 self.tr("Translation file generation"),
                 self.tr(
                     "The generation of the translation files (*.ts) has" " failed.{0}"
@@ -1202,7 +1201,9 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     args.append("--no-obsolete")
 
                 args += ["--ts", lang]
-                args.append(".")
+
+                startPath = self.project.pdata.get("TRANSLATIONSOURCESTARTPATH", "")
+                args.append(startPath if bool(startPath) else ".")
 
                 proc.setWorkingDirectory(self.project.ppath)
                 proc.finished.connect(
@@ -1336,7 +1337,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         ui = ericApp().getObject("UserInterface")
         if exitStatus == QProcess.ExitStatus.NormalExit and exitCode == 0:
             ui.showNotification(
-                UI.PixmapCache.getPixmap("linguist48"),
+                EricPixmapCache.getPixmap("linguist48"),
                 self.tr("Translation file release"),
                 self.tr(
                     "The release of the translation files (*.qm)" " was successful."
@@ -1355,7 +1356,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                             shutil.move(qmFile, target)
         else:
             ui.showNotification(
-                UI.PixmapCache.getPixmap("linguist48"),
+                EricPixmapCache.getPixmap("linguist48"),
                 self.tr("Translation file release"),
                 self.tr("The release of the translation files (*.qm) has failed."),
                 kind=NotificationTypes.CRITICAL,
