@@ -15,18 +15,17 @@ import trove_classifiers
 from PyQt6.QtCore import QDir, pyqtSlot
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .Ui_PropertiesDialog import Ui_PropertiesDialog
 
-from QScintilla.DocstringGenerator import getSupportedDocstringTypes
+from eric7.QScintilla.DocstringGenerator import getSupportedDocstringTypes
 
-from Testing.Interfaces import FrameworkNames
+from eric7.Testing.Interfaces import FrameworkNames
 
-import Utilities
-import Preferences
-import UI.PixmapCache
+from eric7 import Preferences, Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class PropertiesDialog(QDialog, Ui_PropertiesDialog):
@@ -51,7 +50,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         self.dirPicker.setMode(EricPathPickerModes.DIRECTORY_MODE)
         self.mainscriptPicker.setMode(EricPathPickerModes.OPEN_FILE_MODE)
 
-        self.makeButton.setIcon(UI.PixmapCache.getIcon("makefile"))
+        self.makeButton.setIcon(EricPixmapCache.getIcon("makefile"))
 
         self.docstringStyleComboBox.addItem(self.tr("None"), "")
         for docstringType, docstringStyle in sorted(getSupportedDocstringTypes()):
@@ -298,7 +297,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         if self.project.vcs is None:
             return
 
-        from VCS.RepositoryInfoDialog import VcsRepositoryInfoDialog
+        from eric7.VCS.RepositoryInfoDialog import VcsRepositoryInfoDialog
 
         info = self.project.vcs.vcsRepositoryInfos(self.project.ppath)
         dlg = VcsRepositoryInfoDialog(self, info)
