@@ -13,10 +13,10 @@ import typing
 
 from PyQt6.QtCore import QObject
 
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverridenCursor
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverridenCursor
 
-import Preferences
+from eric7 import Preferences
 
 Project = typing.TypeVar("Project")
 
