@@ -19,13 +19,12 @@ from PyQt6.QtGui import QFontInfo
 from PyQt6.QtWidgets import QInputDialog
 from PyQt6.Qsci import QsciScintilla
 
-from EricWidgets import EricMessageBox
-from EricGui.EricOverrideCursor import EricOverrideCursor
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 
 from .ExporterBase import ExporterBase
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 
 class HTMLGenerator:
@@ -565,8 +564,8 @@ class ExporterHTML(ExporterBase):
             )
             return ""
 
-        from UI.Previewers import PreviewerHTMLStyles
-        from UI.Previewers import MarkdownExtensions
+        from eric7.UI.Previewers import PreviewerHTMLStyles
+        from eric7.UI.Previewers import MarkdownExtensions
 
         extensions = []
 
