@@ -7,7 +7,7 @@
 Module implementing the lexer mixin class.
 """
 
-import Preferences
+from eric7 import Preferences
 
 
 class Lexer:
