@@ -13,7 +13,7 @@ import contextlib
 from PyQt6.Qsci import QsciLexerPython, QsciScintilla
 
 from .SubstyledLexer import SubstyledLexer
-import Preferences
+from eric7 import Preferences
 
 
 class LexerPython(SubstyledLexer, QsciLexerPython):
