@@ -33,7 +33,7 @@ from eric7.Debugger.DebugServer import DebugServer
 from eric7.UI.SearchWidget import SearchWidget
 from eric7.VirtualEnv.VirtualenvManager import VirtualenvManager
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class ShellWindow(EricMainWindow):
