@@ -14,8 +14,7 @@ import contextlib
 
 from PyQt6.QtCore import QTimer, QObject
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
 with contextlib.suppress(ImportError, AttributeError, OSError):
     import enchant
