@@ -22,7 +22,7 @@ from PyQt6.QtGui import (
 )
 from PyQt6.QtWidgets import QWidget, QToolTip
 
-import Globals
+from eric7 import Globals
 
 
 def drawRect(painter, rect, outline, fill=None):
