@@ -13,7 +13,7 @@ import os
 
 from PyQt6.QtCore import pyqtSlot, QProcess
 
-from EricNetwork.EricJsonStreamReader import EricJsonReader
+from eric7.EricNetwork.EricJsonStreamReader import EricJsonReader
 
 from .TestExecutorBase import TestExecutorBase, TestResult, TestResultCategory
 
