@@ -14,7 +14,7 @@ import re
 
 from PyQt6.QtCore import pyqtSlot, QProcess
 
-from EricNetwork.EricJsonStreamReader import EricJsonReader
+from eric7.EricNetwork.EricJsonStreamReader import EricJsonReader
 
 from .TestExecutorBase import TestExecutorBase, TestResult, TestResultCategory
 
