@@ -274,7 +274,7 @@ def runtest(argv):
     @param argv list of command line parameters.
     @type list of str
     """
-    from EricNetwork.EricJsonStreamWriter import EricJsonWriter
+    from eric7.EricNetwork.EricJsonStreamWriter import EricJsonWriter
 
     writer = EricJsonWriter(argv[0], int(argv[1]))
     del argv[:2]
@@ -357,7 +357,7 @@ def runtest(argv):
                 )
             ),
         )
-        from DebugClients.Python.coverage import Coverage
+        from eric7.DebugClients.Python.coverage import Coverage
 
         cover = Coverage(data_file=covDataFile)
         if coverageErase:
