@@ -19,7 +19,7 @@ from eric7 import Globals
 
 from eric7.EricGui import EricPixmapCache
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 application = None
 
