@@ -31,10 +31,10 @@ from PyQt6.QtWidgets import (
     QDialog,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricFileDialog, EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricFileDialog, EricMessageBox
 
-from Project.ProjectBrowserModel import ProjectBrowserSimpleDirectoryItem
+from eric7.Project.ProjectBrowserModel import ProjectBrowserSimpleDirectoryItem
 from .BrowserModel import (
     BrowserModel,
     BrowserDirectoryItem,
@@ -50,10 +50,9 @@ from .BrowserModel import (
 )
 from .BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
 
-import UI.PixmapCache
-import Preferences
-import Utilities
-import Utilities.MimeTypes
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences, Utilities
+from eric7.Utilities import MimeTypes
 
 
 class Browser(QTreeView):
@@ -113,7 +112,7 @@ class Browser(QTreeView):
         super().__init__(parent)
 
         self.setWindowTitle(QCoreApplication.translate("Browser", "File-Browser"))
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
+        self.setWindowIcon(EricPixmapCache.getIcon("eric"))
 
         self.__model = BrowserModel()
         self.__sortModel = BrowserSortFilterProxyModel()
@@ -547,7 +546,7 @@ class Browser(QTreeView):
                     elif itm.isEricGraphicsFile():
                         self.umlFile.emit(itm.fileName())
                     else:
-                        if Utilities.MimeTypes.isTextFile(itm.fileName()):
+                        if MimeTypes.isTextFile(itm.fileName()):
                             self.sourceFile[str].emit(itm.fileName())
                         else:
                             QDesktopServices.openUrl(QUrl(itm.fileName()))
@@ -581,7 +580,7 @@ class Browser(QTreeView):
             ]
         )
         if itmList:
-            mimetype = Utilities.MimeTypes.mimeType(itmList[0].fileName())
+            mimetype = MimeTypes.mimeType(itmList[0].fileName())
             if mimetype is None:
                 EricMessageBox.warning(
                     self,
@@ -659,7 +658,7 @@ class Browser(QTreeView):
         itmList = self.getSelectedItems([BrowserFileItem])
 
         for itm in itmList:
-            if Utilities.MimeTypes.isTextFile(itm.fileName()):
+            if MimeTypes.isTextFile(itm.fileName()):
                 self.sourceFile.emit(itm.fileName())
 
     def _copyToClipboard(self):
@@ -1021,7 +1020,7 @@ class Browser(QTreeView):
             s2t = os.remove
             trashMsg = self.tr("Do you really want to delete this file?")
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(), self.tr("Delete File"), trashMsg, [fn]
@@ -1057,7 +1056,7 @@ class Browser(QTreeView):
             s2tAvailable = False
             trashMsg = self.tr("Do you really want to delete this directory?")
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(), self.tr("Delete Directory"), trashMsg, [dn]
@@ -1100,7 +1099,7 @@ class Browser(QTreeView):
             s2t = os.remove
             trashMsg = self.tr("Do you really want to delete these files?")
 
-        from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+        from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
         dlg = DeleteFilesConfirmationDialog(
             self.parent(), self.tr("Delete Files"), trashMsg, sorted(fileNames)
