@@ -24,15 +24,14 @@ from PyQt6.QtWidgets import (
     QVBoxLayout,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
 
 from .Ui_FindFileWidget import Ui_FindFileWidget
 
-import Preferences
-import UI.PixmapCache
-import Utilities
+from eric7 import Preferences, Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class FindFileWidget(QWidget, Ui_FindFileWidget):
@@ -85,9 +84,9 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
 
         self.layout().setContentsMargins(0, 3, 0, 0)
 
-        self.caseToolButton.setIcon(UI.PixmapCache.getIcon("caseSensitive"))
-        self.wordToolButton.setIcon(UI.PixmapCache.getIcon("wholeWord"))
-        self.regexpToolButton.setIcon(UI.PixmapCache.getIcon("regexp"))
+        self.caseToolButton.setIcon(EricPixmapCache.getIcon("caseSensitive"))
+        self.wordToolButton.setIcon(EricPixmapCache.getIcon("wholeWord"))
+        self.regexpToolButton.setIcon(EricPixmapCache.getIcon("regexp"))
 
         self.dirPicker.setMode(EricPathPickerModes.DIRECTORY_MODE)
         self.dirPicker.setInsertPolicy(QComboBox.InsertPolicy.InsertAtTop)
@@ -97,20 +96,20 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
 
         self.stopButton.setEnabled(False)
         self.stopButton.clicked.connect(self.__stopSearch)
-        self.stopButton.setIcon(UI.PixmapCache.getIcon("stopLoading"))
+        self.stopButton.setIcon(EricPixmapCache.getIcon("stopLoading"))
         self.stopButton.setAutoDefault(False)
 
         self.findButton.setEnabled(False)
         self.findButton.clicked.connect(self.__doSearch)
-        self.findButton.setIcon(UI.PixmapCache.getIcon("find"))
+        self.findButton.setIcon(EricPixmapCache.getIcon("find"))
         self.findButton.setAutoDefault(False)
 
         self.clearButton.setEnabled(False)
         self.clearButton.clicked.connect(self.__clearResults)
-        self.clearButton.setIcon(UI.PixmapCache.getIcon("clear"))
+        self.clearButton.setIcon(EricPixmapCache.getIcon("clear"))
         self.clearButton.setAutoDefault(False)
 
-        self.replaceButton.setIcon(UI.PixmapCache.getIcon("editReplace"))
+        self.replaceButton.setIcon(EricPixmapCache.getIcon("editReplace"))
         self.replaceButton.setAutoDefault(False)
 
         self.modeToggleButton.clicked.connect(self.__toggleReplaceMode)
@@ -287,7 +286,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
             font = Preferences.getEditorOtherFonts("MonospacedFont")
             self.findList.setFont(font)
 
-            self.modeToggleButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+            self.modeToggleButton.setIcon(EricPixmapCache.getIcon("1uparrow"))
         else:
             self.replaceLabel.hide()
             self.replacetextCombo.hide()
@@ -295,7 +294,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
 
             self.findList.setFont(self.__standardListFont)
 
-            self.modeToggleButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+            self.modeToggleButton.setIcon(EricPixmapCache.getIcon("1downarrow"))
 
     @pyqtSlot()
     def __projectOpened(self):
