@@ -20,7 +20,7 @@ from .Ui_PreviewerQSS import Ui_PreviewerQSS
 from eric7 import Preferences, Utilities
 from eric7.EricGui import EricPixmapCache
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 
 class PreviewerQSS(QWidget, Ui_PreviewerQSS):
