@@ -23,12 +23,12 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QColor
 from PyQt6.QtWidgets import QWidget, QHeaderView, QAbstractItemView
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_SymbolsWidget import Ui_SymbolsWidget
 
-import UI.PixmapCache
-import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7 import Preferences
 
 
 class SymbolsModel(QAbstractTableModel):
@@ -516,7 +516,7 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         super().__init__(parent)
         self.setupUi(self)
 
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
+        self.setWindowIcon(EricPixmapCache.getIcon("eric"))
 
         self.__model = SymbolsModel(self)
         self.symbolsTable.setModel(self.__model)
