@@ -14,8 +14,8 @@ It is based on the Python class browser found in this package.
 
 import re
 
-import Utilities
-import Utilities.ClassBrowsers as ClassBrowsers
+from eric7 import Utilities
+from eric7.Utilities import ClassBrowsers
 from . import ClbrBaseClasses
 
 SUPPORTED_TYPES = [ClassBrowsers.RB_SOURCE]
