@@ -86,7 +86,7 @@ from eric7.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck import (
     normalizeCode,
 )
 
-from eric7config import getConfig
+from eric7.Globals import getConfig
 
 configDir = None
 
