@@ -11,7 +11,7 @@ from PyQt6.QtWidgets import QDialog
 
 from .Ui_CommandOptionsDialog import Ui_VcsCommandOptionsDialog
 
-import Utilities
+from eric7 import Utilities
 
 
 class VcsCommandOptionsDialog(QDialog, Ui_VcsCommandOptionsDialog):
