@@ -15,13 +15,13 @@ import pathlib
 from PyQt6.QtCore import pyqtSlot, QObject, QCoreApplication
 from PyQt6.QtWidgets import QDialog, QInputDialog, QToolBar
 
-from EricGui.EricAction import EricAction
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricGui.EricAction import EricAction
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Preferences
-import UI.PixmapCache
-import UI.Config
+from eric7 import Preferences
+from eric7.EricGui import EricPixmapCache
+from eric7.UI import Config
 
 
 class VcsProjectHelper(QObject):
@@ -67,7 +67,7 @@ class VcsProjectHelper(QObject):
         """
         self.vcsNewAct = EricAction(
             QCoreApplication.translate("VcsProjectHelper", "New from repository"),
-            UI.PixmapCache.getIcon("vcsCheckout"),
+            EricPixmapCache.getIcon("vcsCheckout"),
             QCoreApplication.translate("VcsProjectHelper", "&New from repository..."),
             0,
             0,
@@ -92,7 +92,7 @@ class VcsProjectHelper(QObject):
 
         self.vcsExportAct = EricAction(
             QCoreApplication.translate("VcsProjectHelper", "Export from repository"),
-            UI.PixmapCache.getIcon("vcsExport"),
+            EricPixmapCache.getIcon("vcsExport"),
             QCoreApplication.translate(
                 "VcsProjectHelper", "&Export from repository..."
             ),
@@ -118,7 +118,7 @@ class VcsProjectHelper(QObject):
 
         self.vcsAddAct = EricAction(
             QCoreApplication.translate("VcsProjectHelper", "Add to repository"),
-            UI.PixmapCache.getIcon("vcsCommit"),
+            EricPixmapCache.getIcon("vcsCommit"),
             QCoreApplication.translate("VcsProjectHelper", "&Add to repository..."),
             0,
             0,
@@ -176,7 +176,7 @@ class VcsProjectHelper(QObject):
         @return the toolbar generated (QToolBar)
         """
         tb = QToolBar(QCoreApplication.translate("VcsProjectHelper", "VCS"), ui)
-        tb.setIconSize(UI.Config.ToolBarIconSize)
+        tb.setIconSize(Config.ToolBarIconSize)
         tb.setObjectName("VersionControlToolbar")
         tb.setToolTip(QCoreApplication.translate("VcsProjectHelper", "VCS"))
 
@@ -342,7 +342,7 @@ class VcsProjectHelper(QObject):
                             self.project.ppath = projectdir
                             self.project.opened = True
 
-                            from Project.PropertiesDialog import PropertiesDialog
+                            from eric7.Project.PropertiesDialog import PropertiesDialog
 
                             dlg = PropertiesDialog(self.project, False)
                             if dlg.exec() == QDialog.DialogCode.Accepted:
