@@ -27,14 +27,13 @@ from PyQt6.QtWidgets import (
     QDialog,
 )
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets import EricMessageBox
-from EricWidgets.EricSpellCheckedTextEdit import EricSpellCheckedTextEdit
-from EricWidgets.EricListSelectionDialog import EricListSelectionDialog
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricSpellCheckedTextEdit import EricSpellCheckedTextEdit
+from eric7.EricWidgets.EricListSelectionDialog import EricListSelectionDialog
 
-import Preferences
-import UI.PixmapCache
-import Utilities
+from eric7 import Preferences, Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class StatusWidget(QWidget):
@@ -75,7 +74,7 @@ class StatusWidget(QWidget):
         self.__topLayout.addWidget(self.__infoLabel)
 
         self.__commitToggleButton = QToolButton(self)
-        self.__commitToggleButton.setIcon(UI.PixmapCache.getIcon("check"))
+        self.__commitToggleButton.setIcon(EricPixmapCache.getIcon("check"))
         self.__commitToggleButton.setToolTip(
             self.tr("Press to toggle the commit markers")
         )
@@ -83,7 +82,7 @@ class StatusWidget(QWidget):
         self.__topLayout.addWidget(self.__commitToggleButton)
 
         self.__commitButton = QToolButton(self)
-        self.__commitButton.setIcon(UI.PixmapCache.getIcon("vcsCommit"))
+        self.__commitButton.setIcon(EricPixmapCache.getIcon("vcsCommit"))
         self.__commitButton.setToolTip(
             self.tr("Press to commit the marked entries with options")
         )
@@ -91,7 +90,7 @@ class StatusWidget(QWidget):
         self.__topLayout.addWidget(self.__commitButton)
 
         self.__addButton = QToolButton(self)
-        self.__addButton.setIcon(UI.PixmapCache.getIcon("vcsAdd"))
+        self.__addButton.setIcon(EricPixmapCache.getIcon("vcsAdd"))
         self.__addButton.setToolTip(
             self.tr("Press to add the selected, untracked entries")
         )
@@ -99,13 +98,13 @@ class StatusWidget(QWidget):
         self.__topLayout.addWidget(self.__addButton)
 
         self.__reloadButton = QToolButton(self)
-        self.__reloadButton.setIcon(UI.PixmapCache.getIcon("reload"))
+        self.__reloadButton.setIcon(EricPixmapCache.getIcon("reload"))
         self.__reloadButton.setToolTip(self.tr("Press to reload the status list"))
         self.__reloadButton.clicked.connect(self.__reload)
         self.__topLayout.addWidget(self.__reloadButton)
 
         self.__actionsButton = QToolButton(self)
-        self.__actionsButton.setIcon(UI.PixmapCache.getIcon("actionsToolButton"))
+        self.__actionsButton.setIcon(EricPixmapCache.getIcon("actionsToolButton"))
         self.__actionsButton.setToolTip(self.tr("Select action from menu"))
         self.__actionsButton.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
         self.__topLayout.addWidget(self.__actionsButton)
@@ -145,7 +144,7 @@ class StatusWidget(QWidget):
         self.__quickCommitLayout2.addStretch()
 
         self.__quickCommitHistoryButton = QToolButton(self)
-        self.__quickCommitHistoryButton.setIcon(UI.PixmapCache.getIcon("history"))
+        self.__quickCommitHistoryButton.setIcon(EricPixmapCache.getIcon("history"))
         self.__quickCommitHistoryButton.setToolTip(
             self.tr("Select commit message from previous commits")
         )
@@ -154,7 +153,7 @@ class StatusWidget(QWidget):
 
         self.__quickCommitHistoryClearButton = QToolButton(self)
         self.__quickCommitHistoryClearButton.setIcon(
-            UI.PixmapCache.getIcon("historyClear")
+            EricPixmapCache.getIcon("historyClear")
         )
         self.__quickCommitHistoryClearButton.setToolTip(
             self.tr("Clear the list of saved commit messages")
@@ -163,7 +162,7 @@ class StatusWidget(QWidget):
         self.__quickCommitLayout2.addWidget(self.__quickCommitHistoryClearButton)
 
         self.__quickCommitButton = QToolButton(self)
-        self.__quickCommitButton.setIcon(UI.PixmapCache.getIcon("vcsCommit"))
+        self.__quickCommitButton.setIcon(EricPixmapCache.getIcon("vcsCommit"))
         self.__quickCommitButton.setToolTip(
             self.tr("Press to commit the marked entries")
         )
@@ -225,7 +224,7 @@ class StatusWidget(QWidget):
         self.__actionsMenu.aboutToShow.connect(self.__showActionsMenu)
 
         self.__commitAct = self.__actionsMenu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit"), self.tr("Commit"), self.__commit
+            EricPixmapCache.getIcon("vcsCommit"), self.tr("Commit"), self.__commit
         )
         self.__commitAct.setToolTip(self.tr("Commit the marked entries with options"))
         self.__commitSelectAct = self.__actionsMenu.addAction(
@@ -238,7 +237,7 @@ class StatusWidget(QWidget):
         self.__actionsMenu.addSeparator()
 
         self.__addAct = self.__actionsMenu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd"), self.tr("Add"), self.__addUntracked
+            EricPixmapCache.getIcon("vcsAdd"), self.tr("Add"), self.__addUntracked
         )
         self.__addAct.setToolTip(self.tr("Add the selected, untracked entries"))
         self.__addAllAct = self.__actionsMenu.addAction(
@@ -249,7 +248,7 @@ class StatusWidget(QWidget):
         self.__actionsMenu.addSeparator()
 
         self.__diffAct = self.__actionsMenu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff"), self.tr("Differences"), self.__diff
+            EricPixmapCache.getIcon("vcsDiff"), self.tr("Differences"), self.__diff
         )
         self.__diffAct.setToolTip(
             self.tr(
@@ -257,7 +256,7 @@ class StatusWidget(QWidget):
             )
         )
         self.__sbsDiffAct = self.__actionsMenu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff"),
+            EricPixmapCache.getIcon("vcsSbsDiff"),
             self.tr("Differences Side-By-Side"),
             self.__sbsDiff,
         )
@@ -277,7 +276,7 @@ class StatusWidget(QWidget):
         self.__actionsMenu.addSeparator()
 
         self.__revertAct = self.__actionsMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert"), self.tr("Revert"), self.__revert
+            EricPixmapCache.getIcon("vcsRevert"), self.tr("Revert"), self.__revert
         )
         self.__revertAct.setToolTip(
             self.tr("Reverts the changes of the selected files")
@@ -296,13 +295,13 @@ class StatusWidget(QWidget):
         self.__actionsMenu.addSeparator()
 
         self.__editAct = self.__actionsMenu.addAction(
-            UI.PixmapCache.getIcon("open"),
+            EricPixmapCache.getIcon("open"),
             self.tr("Edit Conflict"),
             self.__editConflict,
         )
         self.__editAct.setToolTip(self.tr("Edit the selected conflicting file"))
         self.__resolvedAct = self.__actionsMenu.addAction(
-            UI.PixmapCache.getIcon("vcsResolved"),
+            EricPixmapCache.getIcon("vcsResolved"),
             self.tr("Conflict Resolved"),
             self.__conflictResolved,
         )
@@ -425,7 +424,7 @@ class StatusWidget(QWidget):
                 itm = QListWidgetItem(name, self.__statusList)
                 with contextlib.suppress(KeyError):
                     itm.setToolTip(self.__statusTexts[status])
-                    itm.setIcon(UI.PixmapCache.getIcon(self.__statusIcons[status]))
+                    itm.setIcon(EricPixmapCache.getIcon(self.__statusIcons[status]))
                 itm.setData(self.StatusDataRole, status)
                 if status in "AMOR":
                     itm.setFlags(itm.flags() | Qt.ItemFlag.ItemIsUserCheckable)
