@@ -24,10 +24,10 @@ from PyQt6.QtCore import (
 )
 from PyQt6.QtWidgets import QApplication
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Preferences
+from eric7 import Preferences
 
 
 class VersionControl(QObject):
