@@ -13,7 +13,7 @@ some repository information and an abstract base class. The individual
 interfaces have to be subclasses of this base class.
 """
 
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricApplication import ericApp
 
 ######################################################################
 ## Below is the factory function to instantiate the appropriate
