@@ -14,16 +14,12 @@ import re
 from PyQt6.QtCore import pyqtSlot, QProcess, QTimer
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
-from EricWidgets.EricPathPicker import EricPathPickerModes
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_VirtualenvConfigurationDialog import Ui_VirtualenvConfigurationDialog
 
-import Globals
-import Preferences
-import Utilities
-
-import CondaInterface
+from eric7 import CondaInterface, Globals, Preferences, Utilities
 
 
 class VirtualenvConfigurationDialog(QDialog, Ui_VirtualenvConfigurationDialog):
