@@ -15,8 +15,8 @@ from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_VirtualenvExecDialog import Ui_VirtualenvExecDialog
 
-import Preferences
-from Globals import isWindowsPlatform, getPythonExecutable
+from eric7 import Preferences
+from eric7.Globals import isWindowsPlatform, getPythonExecutable
 
 
 class VirtualenvExecDialog(QDialog, Ui_VirtualenvExecDialog):
