@@ -16,11 +16,10 @@ import copy
 from PyQt6.QtCore import pyqtSlot, pyqtSignal, QObject
 from PyQt6.QtWidgets import QDialog
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
-import Globals
-import Preferences
+from eric7 import Globals, Preferences
 
 
 class VirtualenvManager(QObject):
@@ -82,6 +81,7 @@ class VirtualenvManager(QObject):
         #   is_remote:      a flag indicating a remotely accessed environment
         #   exec_path:      a string to be prefixed to the PATH environment
         #                   setting
+        #   description     a description of the environment
         #
         envsToDelete = []
         for venvName in environments:
@@ -97,6 +97,8 @@ class VirtualenvManager(QObject):
                     environment["is_remote"] = False
                 if "exec_path" not in environment:
                     environment["exec_path"] = ""
+                if "description" not in environment:
+                    environment["description"] = ""
                 self.__virtualEnvironments[venvName] = environment
 
         # now remove unsupported environments
@@ -105,22 +107,25 @@ class VirtualenvManager(QObject):
 
         # check, if the interpreter used to run eric is in the environments
         defaultPy = Globals.getPythonExecutable()
-        found = False
-        for venvName in self.__virtualEnvironments:
-            if defaultPy == self.__virtualEnvironments[venvName]["interpreter"]:
-                found = True
-                break
-        if not found:
-            # add an environment entry for the default interpreter
-            self.__virtualEnvironments[VirtualenvManager.DefaultKey] = {
-                "path": "",
-                "interpreter": defaultPy,
-                "variant": 3,
-                "is_global": True,
-                "is_conda": False,
-                "is_remote": False,
-                "exec_path": "",
-            }
+        if "{0}.venv{0}".format(os.sep) not in defaultPy:
+            # only check for a non-embedded environment
+            found = False
+            for venvName in self.__virtualEnvironments:
+                if defaultPy == self.__virtualEnvironments[venvName]["interpreter"]:
+                    found = True
+                    break
+            if not found:
+                # add an environment entry for the default interpreter
+                self.__virtualEnvironments[VirtualenvManager.DefaultKey] = {
+                    "path": "",
+                    "interpreter": defaultPy,
+                    "variant": 3,
+                    "is_global": True,
+                    "is_conda": False,
+                    "is_remote": False,
+                    "exec_path": "",
+                    "description": "",
+                }
 
         self.__saveSettings()
 
@@ -259,6 +264,7 @@ class VirtualenvManager(QObject):
         isConda=False,
         isRemote=False,
         execPath="",
+        description="",
     ):
         """
         Public method to add a virtual environment.
@@ -278,6 +284,8 @@ class VirtualenvManager(QObject):
         @param execPath search path string to be prepended to the PATH
             environment variable
         @type str
+        @param description descriptive text for the environment
+        @type str
         """
         if venvName in self.__virtualEnvironments:
             ok = EricMessageBox.yesNo(
@@ -318,6 +326,7 @@ class VirtualenvManager(QObject):
                 "is_conda": isConda,
                 "is_remote": isRemote,
                 "exec_path": execPath,
+                "description": description,
             }
 
             self.__saveSettings()
@@ -334,6 +343,7 @@ class VirtualenvManager(QObject):
         isConda,
         isRemote,
         execPath,
+        description,
     ):
         """
         Public method to change a virtual environment.
@@ -353,6 +363,8 @@ class VirtualenvManager(QObject):
         @param execPath search path string to be prepended to the PATH
             environment variable
         @type str
+        @param description descriptive text for the environment
+        @type str
         """
         if venvName not in self.__virtualEnvironments:
             EricMessageBox.yesNo(
@@ -374,6 +386,7 @@ class VirtualenvManager(QObject):
             "is_conda": isConda,
             "is_remote": isRemote,
             "exec_path": execPath,
+            "description": description,
         }
 
         self.__saveSettings()
@@ -391,6 +404,7 @@ class VirtualenvManager(QObject):
         isConda,
         isRemote,
         execPath,
+        description,
     ):
         """
         Public method to substitute a virtual environment entry with a new
@@ -413,6 +427,8 @@ class VirtualenvManager(QObject):
         @param execPath search path string to be prepended to the PATH
             environment variable
         @type str
+        @param description descriptive text for the environment
+        @type str
         """
         if oldVenvName not in self.__virtualEnvironments:
             EricMessageBox.yesNo(
@@ -430,11 +446,12 @@ class VirtualenvManager(QObject):
         self.addVirtualEnv(
             venvName,
             venvDirectory,
-            venvInterpreter,
-            isGlobal,
-            isConda,
-            isRemote,
-            execPath,
+            venvInterpreter=venvInterpreter,
+            isGlobal=isGlobal,
+            isConda=isConda,
+            isRemote=isRemote,
+            execPath=execPath,
+            description=description,
         )
 
     def deleteVirtualEnvs(self, venvNames):
@@ -455,7 +472,9 @@ class VirtualenvManager(QObject):
                     )
                 )
         if venvMessages:
-            from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+            from eric7.UI.DeleteFilesConfirmationDialog import (
+                DeleteFilesConfirmationDialog,
+            )
 
             dlg = DeleteFilesConfirmationDialog(
                 None,
@@ -522,7 +541,9 @@ class VirtualenvManager(QObject):
                     )
                 )
         if venvMessages:
-            from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+            from eric7.UI.DeleteFilesConfirmationDialog import (
+                DeleteFilesConfirmationDialog,
+            )
 
             dlg = DeleteFilesConfirmationDialog(
                 None,
