@@ -26,10 +26,9 @@ from PyQt6.QtCore import (
 )
 from PyQt6.QtNetwork import QNetworkReply, QNetworkRequest
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
-import Utilities
-import Preferences
+from eric7 import Preferences, Utilities
 
 
 class AdBlockSubscription(QObject):
@@ -139,7 +138,7 @@ class AdBlockSubscription(QObject):
             QByteArray(urlQuery.queryItemValue("requiresTitle").encode())
         )
         if self.__requiresLocation and self.__requiresTitle:
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
             WebBrowserWindow.adBlockManager().loadRequiredSubscription(
                 self.__requiresLocation, self.__requiresTitle
@@ -407,7 +406,7 @@ class AdBlockSubscription(QObject):
             self.__loadRules()
             return
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         reply = WebBrowserWindow.networkManager().get(QNetworkRequest(self.location()))
         reply.finished.connect(lambda: self.__rulesDownloaded(reply))
@@ -451,7 +450,7 @@ class AdBlockSubscription(QObject):
         fileName = self.rulesFileName()
         try:
             with open(fileName, "wb") as f:
-                from WebBrowser.WebBrowserWindow import WebBrowserWindow
+                from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
                 if (
                     WebBrowserWindow.adBlockManager().useLimitedEasyList()
@@ -674,7 +673,7 @@ class AdBlockSubscription(QObject):
         self.rulesEnabledChanged.emit()
 
         if rule.isCSSRule():
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
             WebBrowserWindow.mainWindow().reloadUserStyleSheet()
 
