@@ -25,12 +25,12 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QUndoStack, QUndoCommand
 from PyQt6.QtWidgets import QDialog
 
-from EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
 
 from .BookmarkNode import BookmarkNode
 
-from Utilities.AutoSaver import AutoSaver
-import Utilities
+from eric7.Utilities.AutoSaver import AutoSaver
+from eric7 import Utilities
 
 BOOKMARKBAR = QT_TRANSLATE_NOOP("BookmarksManager", "Bookmarks Bar")
 BOOKMARKMENU = QT_TRANSLATE_NOOP("BookmarksManager", "Bookmarks Menu")
