@@ -16,16 +16,16 @@ from PyQt6.QtGui import QDesktopServices
 from PyQt6.QtWidgets import QWidget, QStyle, QDialog
 from PyQt6.QtWebEngineCore import QWebEngineDownloadRequest
 
-from EricWidgets import EricFileDialog
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricFileDialog
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_DownloadItem import Ui_DownloadItem
 
 from .DownloadUtilities import timeString, dataString, speedString
-from WebBrowser.WebBrowserWindow import WebBrowserWindow
+from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
-import UI.PixmapCache
-import Utilities.MimeTypes
+from eric7.EricGui import EricPixmapCache
+from eric7.Utilities import MimeTypes
 
 
 class DownloadState(enum.Enum):
@@ -80,9 +80,9 @@ class DownloadItem(QWidget, Ui_DownloadItem):
 
         self.progressBar.setMaximum(0)
 
-        self.pauseButton.setIcon(UI.PixmapCache.getIcon("pause"))
-        self.stopButton.setIcon(UI.PixmapCache.getIcon("stopLoading"))
-        self.openButton.setIcon(UI.PixmapCache.getIcon("open"))
+        self.pauseButton.setIcon(EricPixmapCache.getIcon("pause"))
+        self.stopButton.setIcon(EricPixmapCache.getIcon("stopLoading"))
+        self.openButton.setIcon(EricPixmapCache.getIcon("open"))
         self.openButton.setEnabled(False)
         self.openButton.setVisible(False)
 
@@ -179,7 +179,7 @@ class DownloadItem(QWidget, Ui_DownloadItem):
             from .DownloadAskActionDialog import DownloadAskActionDialog
 
             url = self.__downloadRequest.url()
-            mimetype = Utilities.MimeTypes.mimeType(originalFileName)
+            mimetype = MimeTypes.mimeType(originalFileName)
             dlg = DownloadAskActionDialog(
                 pathlib.Path(originalFileName).name,
                 mimetype,
