@@ -19,20 +19,19 @@ from PyQt6.QtCore import (
 from PyQt6.QtGui import QCursor, QKeySequence, QShortcut
 from PyQt6.QtWidgets import QDialog, QStyle, QFileIconProvider, QMenu, QApplication
 
-from EricWidgets import EricMessageBox
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_DownloadManager import Ui_DownloadManager
 
 from .DownloadModel import DownloadModel
 from .DownloadUtilities import speedString, timeString
 
-from WebBrowser.WebBrowserWindow import WebBrowserWindow
+from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
-from Utilities.AutoSaver import AutoSaver
-import UI.PixmapCache
-import Preferences
-import Globals
+from eric7.Utilities.AutoSaver import AutoSaver
+from eric7.EricGui import EricPixmapCache
+from eric7 import Globals, Preferences
 
 
 class DownloadManager(QDialog, Ui_DownloadManager):
@@ -110,13 +109,13 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             itm = self.__downloads[row]
             if itm.downloadedSuccessfully():
                 menu.addAction(
-                    UI.PixmapCache.getIcon("open"),
+                    EricPixmapCache.getIcon("open"),
                     self.tr("Open"),
                     self.__contextMenuOpen,
                 )
             elif itm.downloading():
                 menu.addAction(
-                    UI.PixmapCache.getIcon("stopLoading"),
+                    EricPixmapCache.getIcon("stopLoading"),
                     self.tr("Cancel"),
                     self.__contextMenuCancel,
                 )
@@ -248,7 +247,9 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         self.__closeDownloadTab(url)
 
         # Safe Browsing
-        from WebBrowser.SafeBrowsing.SafeBrowsingManager import SafeBrowsingManager
+        from eric7.WebBrowser.SafeBrowsing.SafeBrowsingManager import (
+            SafeBrowsingManager,
+        )
 
         if SafeBrowsingManager.isEnabled():
             threatLists = WebBrowserWindow.safeBrowsingManager().lookupUrl(url)[0]
@@ -410,7 +411,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         if self.removePolicy() == DownloadManager.RemoveExit:
             return
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         if WebBrowserWindow.isPrivate():
             return
@@ -433,7 +434,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         pos = Preferences.getWebBrowser("DownloadManagerPosition")
         self.move(pos)
 
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         if not WebBrowserWindow.isPrivate():
             downloads = Preferences.getWebBrowser("DownloadManagerDownloads")
@@ -499,7 +500,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             # all active downloads are done
             if success and ericApp().activeWindow() is not self:
                 WebBrowserWindow.showNotification(
-                    UI.PixmapCache.getPixmap("downloads48"),
+                    EricPixmapCache.getPixmap("downloads48"),
                     self.tr("Downloads finished"),
                     self.tr("All files have been downloaded."),
                 )
