@@ -26,11 +26,10 @@ from PyQt6.QtCore import (
     QObject,
 )
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
-from Utilities.AutoSaver import AutoSaver
-import Utilities
-import Preferences
+from eric7.Utilities.AutoSaver import AutoSaver
+from eric7 import Preferences, Utilities
 
 HISTORY_VERSION_42 = 42
 HISTORY_VERSION_60 = 60
@@ -241,9 +240,9 @@ class HistoryManager(QObject):
         @param view reference to the view to add an entry for
         @type WebBrowserView
         """
-        import WebBrowser.WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
-        if WebBrowser.WebBrowserWindow.WebBrowserWindow.isPrivate():
+        if WebBrowserWindow.isPrivate():
             return
 
         url = view.url()
