@@ -40,7 +40,7 @@ class PasswordManagerJsObject(QObject):
         @param data data to be submitted
         @type QByteArray
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         WebBrowserWindow.passwordManager().formSubmitted(
             urlStr, userName, password, data, self.__external.page()
