@@ -21,7 +21,7 @@ from PyQt6.QtCore import (
 )
 from PyQt6.QtNetwork import QNetworkRequest, QNetworkReply
 
-from WebBrowser.WebBrowserWindow import WebBrowserWindow
+from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
 from .SafeBrowsingThreatList import ThreatList
 
