@@ -27,11 +27,10 @@ from PyQt6.QtCore import (
     QTimer,
 )
 
-import Preferences
-import Utilities
+from eric7 import Preferences, Utilities
 
-import UI.PixmapCache
-from UI.NotificationWidget import NotificationTypes
+from eric7.EricGui import EricPixmapCache
+from eric7.UI.NotificationWidget import NotificationTypes
 
 from .SafeBrowsingAPIClient import SafeBrowsingAPIClient
 from .SafeBrowsingCache import SafeBrowsingCache
@@ -161,7 +160,7 @@ class SafeBrowsingManager(QObject):
             (0 = indefinitely)
         @type int
         """
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         kind = (
             NotificationTypes.CRITICAL
@@ -170,7 +169,7 @@ class SafeBrowsingManager(QObject):
         )
 
         WebBrowserWindow.showNotification(
-            UI.PixmapCache.getPixmap("safeBrowsing48"),
+            EricPixmapCache.getPixmap("safeBrowsing48"),
             self.tr("Google Safe Browsing"),
             message,
             kind=kind,
@@ -371,7 +370,7 @@ class SafeBrowsingManager(QObject):
         Public slot to show the safe browsing management dialog.
         """
         if self.__gsbDialog is None:
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
             from .SafeBrowsingDialog import SafeBrowsingDialog
 
             self.__gsbDialog = SafeBrowsingDialog(
