@@ -18,13 +18,13 @@ from PyQt6.QtCore import pyqtSlot, Qt, QUrl
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QAbstractButton, QListWidgetItem
 from PyQt6.QtNetwork import QNetworkRequest, QNetworkReply, QNetworkInformation
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
 from .Ui_ManageDictionariesDialog import Ui_ManageDictionariesDialog
 
-from WebBrowser.WebBrowserWindow import WebBrowserWindow
+from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
-import Preferences
+from eric7 import Preferences
 
 
 class ManageDictionariesDialog(QDialog, Ui_ManageDictionariesDialog):
@@ -240,7 +240,9 @@ class ManageDictionariesDialog(QDialog, Ui_ManageDictionariesDialog):
         listFileData = reply.readAll()
 
         # extract the dictionaries
-        from EricXML.SpellCheckDictionariesReader import SpellCheckDictionariesReader
+        from eric7.EricXML.SpellCheckDictionariesReader import (
+            SpellCheckDictionariesReader,
+        )
 
         reader = SpellCheckDictionariesReader(listFileData, self.addEntry)
         reader.readXML()
