@@ -26,14 +26,13 @@ from PyQt6.QtWidgets import (
     QStyle,
 )
 
-from EricNetwork import EricTldExtractor, EricNetworkUtilities
+from eric7.EricNetwork import EricTldExtractor, EricNetworkUtilities
 
-from EricWidgets.EricApplication import ericApp
-from EricWidgets.EricClickableLabel import EricClickableLabel
+from eric7.EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets.EricClickableLabel import EricClickableLabel
 
-import Utilities
-import UI.PixmapCache
-import Preferences
+from eric7 import Preferences, Utilities
+from eric7.EricGui import EricPixmapCache
 
 
 class TabManagerWidget(QWidget):
@@ -291,7 +290,7 @@ class TabManagerWidget(QWidget):
                 if not browser.isLoading():
                     tabItem.setIcon(0, browser.icon())
                 else:
-                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading"))
+                    tabItem.setIcon(0, EricPixmapCache.getIcon("loading"))
                 tabItem.setText(0, browser.title())
                 tabItem.setToolTip(0, browser.title())
 
@@ -333,7 +332,7 @@ class TabManagerWidget(QWidget):
                 if not browser.isLoading():
                     tabItem.setIcon(0, browser.icon())
                 else:
-                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading"))
+                    tabItem.setIcon(0, EricPixmapCache.getIcon("loading"))
                 tabItem.setText(0, browser.title())
                 tabItem.setToolTip(0, browser.title())
 
@@ -528,12 +527,12 @@ class TabManagerWidget(QWidget):
 
         if self.__isBrowserSelected():
             act1 = menu.addAction(
-                UI.PixmapCache.getIcon("bookmark22"), self.tr("&Bookmark checked tabs")
+                EricPixmapCache.getIcon("bookmark22"), self.tr("&Bookmark checked tabs")
             )
             act1.setObjectName("bookmarkSelection")
             act1.triggered.connect(lambda: self.__processActions(act1))
             act2 = menu.addAction(
-                UI.PixmapCache.getIcon("tabClose"), self.tr("&Close checked tabs")
+                EricPixmapCache.getIcon("tabClose"), self.tr("&Close checked tabs")
             )
             act2.setObjectName("closeSelection")
             act2.triggered.connect(lambda: self.__processActions(act2))
@@ -564,7 +563,7 @@ class TabManagerWidget(QWidget):
         @rtype EricClickableLabel
         """
         icon = EricClickableLabel()
-        icon.setPixmap(UI.PixmapCache.getPixmap("tabManager").scaled(16, 16))
+        icon.setPixmap(EricPixmapCache.getPixmap("tabManager").scaled(16, 16))
         icon.setToolTip(self.tr("Show Tab Manager"))
         icon.clicked.connect(lambda: self.raiseTabManager(icon))
 
