@@ -9,7 +9,7 @@ Module implementing the label to show some SSL info (if available).
 
 from PyQt6.QtCore import Qt
 
-from EricWidgets.EricClickableLabel import EricClickableLabel
+from eric7.EricWidgets.EricClickableLabel import EricClickableLabel
 
 
 class SslLabel(EricClickableLabel):
