@@ -14,9 +14,11 @@ import json
 from PyQt6.QtCore import pyqtSignal, QObject, QUrl, QUrlQuery, QByteArray
 from PyQt6.QtNetwork import QNetworkRequest, QNetworkReply
 
-from EricWidgets import EricMessageBox
+from eric7.EricWidgets import EricMessageBox
 
-import Preferences
+from eric7 import Preferences
+
+from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
 
 class VirusTotalAPI(QObject):
@@ -121,9 +123,7 @@ class VirusTotalAPI(QObject):
             )
         )
 
-        import WebBrowser.WebBrowserWindow
-
-        nam = WebBrowser.WebBrowserWindow.WebBrowserWindow.networkManager()
+        nam = WebBrowserWindow.networkManager()
         reply = nam.post(request, params)
         reply.finished.connect(lambda: self.__checkServiceKeyValidityFinished(reply))
         self.__replies.append(reply)
@@ -166,9 +166,7 @@ class VirusTotalAPI(QObject):
             ).encode("utf-8")
         ).append(QUrl.toPercentEncoding(url.toString()))
 
-        import WebBrowser.WebBrowserWindow
-
-        nam = WebBrowser.WebBrowserWindow.WebBrowserWindow.networkManager()
+        nam = WebBrowserWindow.networkManager()
         reply = nam.post(request, params)
         reply.finished.connect(lambda: self.__submitUrlFinished(reply))
         self.__replies.append(reply)
@@ -216,9 +214,7 @@ class VirusTotalAPI(QObject):
             ).encode("utf-8")
         )
 
-        import WebBrowser.WebBrowserWindow
-
-        nam = WebBrowser.WebBrowserWindow.WebBrowserWindow.networkManager()
+        nam = WebBrowserWindow.networkManager()
         reply = nam.post(request, params)
         reply.finished.connect(lambda: self.__getUrlScanReportUrlFinished(reply))
         self.__replies.append(reply)
@@ -255,9 +251,7 @@ class VirusTotalAPI(QObject):
             ).encode("utf-8")
         )
 
-        import WebBrowser.WebBrowserWindow
-
-        nam = WebBrowser.WebBrowserWindow.WebBrowserWindow.networkManager()
+        nam = WebBrowserWindow.networkManager()
         reply = nam.post(request, params)
         reply.finished.connect(lambda: self.__getFileScanReportUrlFinished(reply))
         self.__replies.append(reply)
@@ -295,9 +289,7 @@ class VirusTotalAPI(QObject):
         url.setQuery(query)
         request = QNetworkRequest(url)
 
-        import WebBrowser.WebBrowserWindow
-
-        nam = WebBrowser.WebBrowserWindow.WebBrowserWindow.networkManager()
+        nam = WebBrowserWindow.networkManager()
         reply = nam.get(request)
         reply.finished.connect(lambda: self.__getIpAddressReportFinished(reply))
         self.__replies.append(reply)
@@ -362,9 +354,7 @@ class VirusTotalAPI(QObject):
         url.setQuery(query)
         request = QNetworkRequest(url)
 
-        import WebBrowser.WebBrowserWindow
-
-        nam = WebBrowser.WebBrowserWindow.WebBrowserWindow.networkManager()
+        nam = WebBrowserWindow.networkManager()
         reply = nam.get(request)
         reply.finished.connect(lambda: self.__getDomainReportFinished(reply))
         self.__replies.append(reply)
