@@ -40,10 +40,10 @@ from PyQt6.QtWidgets import QStyle, QMenu, QApplication, QDialog
 from PyQt6.QtWebEngineCore import QWebEnginePage, QWebEngineDownloadRequest
 from PyQt6.QtWebEngineWidgets import QWebEngineView
 
-from EricWidgets import EricMessageBox, EricFileDialog
-from EricWidgets.EricApplication import ericApp
+from eric7.EricWidgets import EricMessageBox, EricFileDialog
+from eric7.EricWidgets.EricApplication import ericApp
 
-from WebBrowser.WebBrowserWindow import WebBrowserWindow
+from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 from .WebBrowserPage import WebBrowserPage
 
 from .Tools.WebIconLoader import WebIconLoader
@@ -52,11 +52,10 @@ from .Tools import Scripts
 from . import WebInspector
 from .Tools.WebBrowserTools import getHtmlPage, pixmapToDataUrl
 
-import Preferences
-import UI.PixmapCache
-import Utilities
+from eric7 import Preferences, Utilities
+from eric7.EricGui import EricPixmapCache
 
-from Globals import qVersionTuple
+from eric7.Globals import qVersionTuple
 
 
 class WebBrowserView(QWebEngineView):
@@ -471,7 +470,7 @@ class WebBrowserView(QWebEngineView):
             self.setZoomFactor(value / 100.0)
             self.__currentZoom = value
             if saveValue and not self.__mw.isPrivate():
-                from .ZoomManager import ZoomManager
+                from eric7.WebBrowser.ZoomManager import ZoomManager
 
                 ZoomManager.instance().setZoomValue(self.url(), value)
             self.zoomValueChanged.emit(value)
@@ -598,7 +597,7 @@ class WebBrowserView(QWebEngineView):
 
         self.__menu.addSeparator()
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("webInspector"),
+            EricPixmapCache.getIcon("webInspector"),
             self.tr("Inspect Element..."),
             self.__webInspector,
         )
@@ -688,40 +687,40 @@ class WebBrowserView(QWebEngineView):
             menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("openNewTab"),
+            EricPixmapCache.getIcon("openNewTab"),
             self.tr("Open Link in New Tab\tCtrl+LMB"),
         )
         act.setData(hitTest.linkUrl())
         act.triggered.connect(functools.partial(self.__openLinkInNewTab, act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("newWindow"), self.tr("Open Link in New Window")
+            EricPixmapCache.getIcon("newWindow"), self.tr("Open Link in New Window")
         )
         act.setData(hitTest.linkUrl())
         act.triggered.connect(functools.partial(self.__openLinkInNewWindow, act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("privateMode"),
+            EricPixmapCache.getIcon("privateMode"),
             self.tr("Open Link in New Private Window"),
         )
         act.setData(hitTest.linkUrl())
         act.triggered.connect(functools.partial(self.__openLinkInNewPrivateWindow, act))
         menu.addSeparator()
         menu.addAction(
-            UI.PixmapCache.getIcon("download"),
+            EricPixmapCache.getIcon("download"),
             self.tr("Save Lin&k"),
             self.__downloadLink,
         )
         act = menu.addAction(
-            UI.PixmapCache.getIcon("bookmark22"), self.tr("Bookmark this Link")
+            EricPixmapCache.getIcon("bookmark22"), self.tr("Bookmark this Link")
         )
         act.setData(hitTest.linkUrl())
         act.triggered.connect(functools.partial(self.__bookmarkLink, act))
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy URL to Clipboard")
         )
         act.setData(hitTest.linkUrl())
         act.triggered.connect(functools.partial(self.__copyLink, act))
-        act = menu.addAction(UI.PixmapCache.getIcon("mailSend"), self.tr("Send URL"))
+        act = menu.addAction(EricPixmapCache.getIcon("mailSend"), self.tr("Send URL"))
         act.setData(hitTest.linkUrl())
         act.triggered.connect(functools.partial(self.__sendLink, act))
         if (
@@ -729,7 +728,7 @@ class WebBrowserView(QWebEngineView):
             and Preferences.getWebBrowser("VirusTotalServiceKey") != ""
         ):
             act = menu.addAction(
-                UI.PixmapCache.getIcon("virustotal"),
+                EricPixmapCache.getIcon("virustotal"),
                 self.tr("Scan Link with VirusTotal"),
             )
             act.setData(hitTest.linkUrl())
@@ -748,24 +747,24 @@ class WebBrowserView(QWebEngineView):
             menu.addSeparator()
 
         act = menu.addAction(
-            UI.PixmapCache.getIcon("openNewTab"), self.tr("Open Image in New Tab")
+            EricPixmapCache.getIcon("openNewTab"), self.tr("Open Image in New Tab")
         )
         act.setData(hitTest.imageUrl())
         act.triggered.connect(functools.partial(self.__openLinkInNewTab, act))
         menu.addSeparator()
         menu.addAction(
-            UI.PixmapCache.getIcon("download"),
+            EricPixmapCache.getIcon("download"),
             self.tr("Save Image"),
             self.__downloadImage,
         )
         menu.addAction(self.tr("Copy Image to Clipboard"), self.__copyImage)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy Image URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy Image URL to Clipboard")
         )
         act.setData(hitTest.imageUrl())
         act.triggered.connect(functools.partial(self.__copyLink, act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend"), self.tr("Send Image URL")
+            EricPixmapCache.getIcon("mailSend"), self.tr("Send Image URL")
         )
         act.setData(hitTest.imageUrl())
         act.triggered.connect(functools.partial(self.__sendLink, act))
@@ -775,7 +774,7 @@ class WebBrowserView(QWebEngineView):
             engine = WebBrowserWindow.imageSearchEngine()
             searchEngineName = engine.searchEngine()
             act = menu.addAction(
-                UI.PixmapCache.getIcon("{0}".format(searchEngineName.lower())),
+                EricPixmapCache.getIcon("{0}".format(searchEngineName.lower())),
                 self.tr("Search image in {0}").format(searchEngineName),
             )
             act.setData(engine.getSearchQuery(hitTest.imageUrl()))
@@ -783,7 +782,7 @@ class WebBrowserView(QWebEngineView):
             self.__imageSearchMenu = menu.addMenu(self.tr("Search image with..."))
             for searchEngineName in engine.searchEngineNames():
                 act = self.__imageSearchMenu.addAction(
-                    UI.PixmapCache.getIcon("{0}".format(searchEngineName.lower())),
+                    EricPixmapCache.getIcon("{0}".format(searchEngineName.lower())),
                     self.tr("Search image in {0}").format(searchEngineName),
                 )
                 act.setData(engine.getSearchQuery(hitTest.imageUrl(), searchEngineName))
@@ -791,7 +790,7 @@ class WebBrowserView(QWebEngineView):
 
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("adBlockPlus"), self.tr("Block Image")
+            EricPixmapCache.getIcon("adBlockPlus"), self.tr("Block Image")
         )
         act.setData(hitTest.imageUrl().toString())
         act.triggered.connect(functools.partial(self.__blockImage, act))
@@ -800,7 +799,7 @@ class WebBrowserView(QWebEngineView):
             and Preferences.getWebBrowser("VirusTotalServiceKey") != ""
         ):
             act = menu.addAction(
-                UI.PixmapCache.getIcon("virustotal"),
+                EricPixmapCache.getIcon("virustotal"),
                 self.tr("Scan Image with VirusTotal"),
             )
             act.setData(hitTest.imageUrl())
@@ -820,41 +819,41 @@ class WebBrowserView(QWebEngineView):
 
         if hitTest.mediaPaused():
             menu.addAction(
-                UI.PixmapCache.getIcon("mediaPlaybackStart"),
+                EricPixmapCache.getIcon("mediaPlaybackStart"),
                 self.tr("Play"),
                 self.__pauseMedia,
             )
         else:
             menu.addAction(
-                UI.PixmapCache.getIcon("mediaPlaybackPause"),
+                EricPixmapCache.getIcon("mediaPlaybackPause"),
                 self.tr("Pause"),
                 self.__pauseMedia,
             )
         if hitTest.mediaMuted():
             menu.addAction(
-                UI.PixmapCache.getIcon("audioVolumeHigh"),
+                EricPixmapCache.getIcon("audioVolumeHigh"),
                 self.tr("Unmute"),
                 self.__muteMedia,
             )
         else:
             menu.addAction(
-                UI.PixmapCache.getIcon("audioVolumeMuted"),
+                EricPixmapCache.getIcon("audioVolumeMuted"),
                 self.tr("Mute"),
                 self.__muteMedia,
             )
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy Media URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy Media URL to Clipboard")
         )
         act.setData(hitTest.mediaUrl())
         act.triggered.connect(functools.partial(self.__copyLink, act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend"), self.tr("Send Media URL")
+            EricPixmapCache.getIcon("mailSend"), self.tr("Send Media URL")
         )
         act.setData(hitTest.mediaUrl())
         act.triggered.connect(functools.partial(self.__sendLink, act))
         menu.addAction(
-            UI.PixmapCache.getIcon("download"),
+            EricPixmapCache.getIcon("download"),
             self.tr("Save Media"),
             self.__downloadMedia,
         )
@@ -873,7 +872,7 @@ class WebBrowserView(QWebEngineView):
 
         menu.addAction(self.__mw.copyAct)
         menu.addSeparator()
-        act = menu.addAction(UI.PixmapCache.getIcon("mailSend"), self.tr("Send Text"))
+        act = menu.addAction(EricPixmapCache.getIcon("mailSend"), self.tr("Send Text"))
         act.setData(self.selectedText())
         act.triggered.connect(functools.partial(self.__sendLink, act))
 
@@ -914,7 +913,7 @@ class WebBrowserView(QWebEngineView):
                 )
             )
             act = menu.addAction(
-                UI.PixmapCache.getIcon("translate"), self.tr("Google Translate")
+                EricPixmapCache.getIcon("translate"), self.tr("Google Translate")
             )
             act.setData(googleTranslatorUrl)
             act.triggered.connect(functools.partial(self.__openLinkInNewTab, act))
@@ -924,7 +923,7 @@ class WebBrowserView(QWebEngineView):
                 )
             )
             act = menu.addAction(
-                UI.PixmapCache.getIcon("wikipedia"), self.tr("Dictionary")
+                EricPixmapCache.getIcon("wikipedia"), self.tr("Dictionary")
             )
             act.setData(wiktionaryUrl)
             act.triggered.connect(functools.partial(self.__openLinkInNewTab, act))
@@ -957,18 +956,18 @@ class WebBrowserView(QWebEngineView):
             menu.addAction(self.__mw.forwardAct)
             menu.addSeparator()
             menu.addAction(
-                UI.PixmapCache.getIcon("plus"),
+                EricPixmapCache.getIcon("plus"),
                 self.tr("Add New Page"),
                 self.__addSpeedDial,
             )
             menu.addAction(
-                UI.PixmapCache.getIcon("preferences-general"),
+                EricPixmapCache.getIcon("preferences-general"),
                 self.tr("Configure Speed Dial"),
                 self.__configureSpeedDial,
             )
             menu.addSeparator()
             menu.addAction(
-                UI.PixmapCache.getIcon("reload"),
+                EricPixmapCache.getIcon("reload"),
                 self.tr("Reload All Dials"),
                 self.__reloadAllSpeedDials,
             )
@@ -977,17 +976,17 @@ class WebBrowserView(QWebEngineView):
             return
 
         menu.addAction(
-            UI.PixmapCache.getIcon("bookmark22"),
+            EricPixmapCache.getIcon("bookmark22"),
             self.tr("Bookmark this Page"),
             self.addBookmark,
         )
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy"), self.tr("Copy Page URL to Clipboard")
+            EricPixmapCache.getIcon("editCopy"), self.tr("Copy Page URL to Clipboard")
         )
         act.setData(self.url())
         act.triggered.connect(functools.partial(self.__copyLink, act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend"), self.tr("Send Page URL")
+            EricPixmapCache.getIcon("mailSend"), self.tr("Send Page URL")
         )
         act.setData(self.url())
         act.triggered.connect(functools.partial(self.__sendLink, act))
@@ -1022,7 +1021,9 @@ class WebBrowserView(QWebEngineView):
                 b"http://validator.w3.org/check?uri="
                 + QUrl.toPercentEncoding(bytes(self.url().toEncoded()).decode())
             )
-            act = menu.addAction(UI.PixmapCache.getIcon("w3"), self.tr("Validate Page"))
+            act = menu.addAction(
+                EricPixmapCache.getIcon("w3"), self.tr("Validate Page")
+            )
             act.setData(w3url)
             act.triggered.connect(functools.partial(self.__openLinkInNewTab, act))
 
@@ -1044,7 +1045,7 @@ class WebBrowserView(QWebEngineView):
                     + QUrl.toPercentEncoding(bytes(self.url().toEncoded()).decode())
                 )
                 act = menu.addAction(
-                    UI.PixmapCache.getIcon("translate"), self.tr("Google Translate")
+                    EricPixmapCache.getIcon("translate"), self.tr("Google Translate")
                 )
                 act.setData(googleTranslatorUrl)
                 act.triggered.connect(functools.partial(self.__openLinkInNewTab, act))
@@ -1716,7 +1717,7 @@ class WebBrowserView(QWebEngineView):
         """
         self.__siteIcon = icon
 
-        from .Tools import WebIconProvider
+        from eric7.WebBrowser.Tools import WebIconProvider
 
         WebIconProvider.instance().saveIcon(self)
 
@@ -1732,7 +1733,7 @@ class WebBrowserView(QWebEngineView):
         if not self.__siteIcon.isNull():
             return QIcon(self.__siteIcon)
 
-        from .Tools import WebIconProvider
+        from eric7.WebBrowser.Tools import WebIconProvider
 
         return WebIconProvider.instance().iconForUrl(self.url())
 
@@ -1870,7 +1871,7 @@ class WebBrowserView(QWebEngineView):
         QApplication.processEvents()
         QTimer.singleShot(200, self.__renderPreview)
 
-        from .ZoomManager import ZoomManager
+        from eric7.WebBrowser.ZoomManager import ZoomManager
 
         zoomValue = ZoomManager.instance().zoomValue(self.url())
         self.setZoomValue(zoomValue)
@@ -1895,7 +1896,7 @@ class WebBrowserView(QWebEngineView):
         """
         modified = QDateTime.fromString(lastModified, "MM/dd/yyyy hh:mm:ss")
         if modified.isValid():
-            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
             from .Bookmarks.BookmarkNode import BookmarkNode
 
             manager = WebBrowserWindow.bookmarksManager()
@@ -2274,7 +2275,7 @@ class WebBrowserView(QWebEngineView):
             icon = QIcon()
             stream >> icon
         else:
-            from .Tools import WebIconProvider
+            from eric7.WebBrowser.Tools import WebIconProvider
 
             icon = WebIconProvider.instance().iconForUrl(QUrl.fromUserInput(urlStr))
 
@@ -2367,7 +2368,7 @@ class WebBrowserView(QWebEngineView):
             clientCertificateSelection.select(certificates[0])
         else:
             certificate = None
-            from EricNetwork.EricSslCertificateSelectionDialog import (
+            from eric7.EricNetwork.EricSslCertificateSelectionDialog import (
                 EricSslCertificateSelectionDialog,
             )
 
